@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -27,7 +27,7 @@ import sys
 import traceback
 from os.path import basename
 from types import CodeType, ModuleType
-from typing import Callable, List
+from typing import Callable
 
 # Bokeh imports
 from ...core.types import PathLike
@@ -53,8 +53,6 @@ __all__ = (
 class CodeRunner:
     ''' Compile and run Python source code.
 
-    .. autoclasstoc::
-
     '''
 
     _code: CodeType | None
@@ -63,7 +61,7 @@ class CodeRunner:
     _permanent_error_detail: str | None
     _path: PathLike
     _source: str
-    _argv: List[str]
+    _argv: list[str]
     _package: ModuleType | None
     ran: bool
 
@@ -71,7 +69,7 @@ class CodeRunner:
     _error: str | None
     _error_detail: str | None
 
-    def __init__(self, source: str, path: PathLike, argv: List[str], package: ModuleType | None = None) -> None:
+    def __init__(self, source: str, path: PathLike, argv: list[str], package: ModuleType | None = None) -> None:
         '''
 
         Args:
@@ -222,7 +220,7 @@ class CodeRunner:
         _sys_path = list(sys.path)
         _sys_argv = list(sys.argv)
         sys.path.insert(0, os.path.dirname(self._path))
-        sys.argv = [os.path.basename(self._path)] + self._argv
+        sys.argv = [os.path.basename(self._path), *self._argv]
 
         # XXX: self._code shouldn't be None at this point but types don't reflect this
         assert self._code is not None
