@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -56,13 +56,7 @@ from os.path import (
     join,
 )
 from types import ModuleType
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Coroutine,
-    Dict,
-    List,
-)
+from typing import TYPE_CHECKING, Any, Coroutine
 
 # External imports
 from jinja2 import Environment, FileSystemLoader, Template
@@ -101,9 +95,6 @@ __all__ = (
 
 class DirectoryHandler(Handler):
     ''' Load an application directory which modifies a Document.
-
-    .. autoclasstoc::
-
     '''
 
     _package_runner: CodeRunner | None
@@ -116,7 +107,7 @@ class DirectoryHandler(Handler):
     _static: str | None
     _template: Template | None
 
-    def __init__(self, *, filename: PathLike, argv: List[str] = []) -> None:
+    def __init__(self, *, filename: PathLike, argv: list[str] = []) -> None:
         '''
         Keywords:
             filename (str) : a path to an application directory with either "main.py" or "main.ipynb"
@@ -129,7 +120,8 @@ class DirectoryHandler(Handler):
 
         init_py = join(src_path, '__init__.py')
         if exists(init_py):
-            self._package_runner = CodeRunner(open(init_py).read(), init_py, argv)
+            with open(init_py, encoding="utf8") as init_py_f:
+                self._package_runner = CodeRunner(init_py_f.read(), init_py, argv)
             self._package = self._package_runner.new_module()
             assert self._package is not None
             sys.modules[self._package.__name__] = self._package
@@ -297,7 +289,7 @@ class DirectoryHandler(Handler):
         '''
         return self._lifecycle_handler.on_session_destroyed(session_context)
 
-    def process_request(self, request: HTTPServerRequest) -> Dict[str, Any]:
+    def process_request(self, request: HTTPServerRequest) -> dict[str, Any]:
         ''' Processes incoming HTTP request returning a dictionary of
         additional data to add to the session_context.
 
