@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -25,12 +25,7 @@ import colorsys
 from abc import ABCMeta, abstractmethod
 from math import sqrt
 from re import match
-from typing import (
-    TYPE_CHECKING,
-    Tuple,
-    TypeVar,
-    Union,
-)
+from typing import TYPE_CHECKING, TypeVar, Union
 
 # Bokeh imports
 from ..core.serialization import AnyRep, Serializable, Serializer
@@ -52,7 +47,7 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-RGBTuple = Union[Tuple[int, int, int], Tuple[int, int, int, float]]
+RGBTuple = Union[tuple[int, int, int], tuple[int, int, int, float]]
 
 ColorLike: TypeAlias = Union[str, "Color", RGBTuple]
 
@@ -342,9 +337,9 @@ class RGB(Color):
 
         '''
         if self.a < 1.0:
-            return "#%02X%02X%02X%02X" % (self.r, self.g, self.b, round(self.a*255))
+            return f"#{self.r:02x}{self.g:02x}{self.b:02x}{int(round(self.a*255)):02x}"
         else:
-            return "#%02X%02X%02X" % (self.r, self.g, self.b)
+            return f"#{self.r:02x}{self.g:02x}{self.b:02x}"
 
     def to_hsl(self) -> HSL:
         ''' Return a corresponding HSL color for this RGB color.
