@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -50,7 +50,7 @@ from typing import Sequence
 # Bokeh imports
 from bokeh import __version__
 from bokeh.settings import settings
-from bokeh.util.string import nice_join
+from bokeh.util.strings import nice_join
 
 # Bokeh imports
 from . import subcommands
