@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -25,7 +25,6 @@ import argparse
 import sys
 from abc import abstractmethod
 from os.path import splitext
-from typing import List, Union
 
 # Bokeh imports
 from ...document import Document
@@ -87,7 +86,7 @@ class FileOutputSubcommand(Subcommand):
             metavar='DIRECTORY-OR-SCRIPT',
             nargs='+',
             help=("The app directories or scripts to generate %s for" % (output_type_name)),
-            default=None
+            default=None,
         ))
 
     @classmethod
@@ -118,7 +117,7 @@ class FileOutputSubcommand(Subcommand):
                 metavar='FILENAME',
                 action='append',
                 type=str,
-                help="Name of the output file or - for standard output."
+                help="Name of the output file or - for standard output.",
             )),
 
             ('--args', Argument(
@@ -137,7 +136,7 @@ class FileOutputSubcommand(Subcommand):
         else:
             base = route[1:]
 
-        return "%s.%s" % (base, ext)
+        return f"{base}.{ext}"
 
     def invoke(self, args: argparse.Namespace) -> None:
         '''
@@ -147,7 +146,7 @@ class FileOutputSubcommand(Subcommand):
         applications = build_single_handler_applications(args.files, argvs)
 
         if args.output is None:
-            outputs: List[str] = []
+            outputs: list[str] = []
         else:
             outputs = list(args.output)  # copy so we can pop from it
 
@@ -214,7 +213,7 @@ class FileOutputSubcommand(Subcommand):
         pass
 
     @abstractmethod
-    def file_contents(self, args: argparse.Namespace, doc: Document) -> Union[str, bytes, List[str], List[bytes]]:
+    def file_contents(self, args: argparse.Namespace, doc: Document) -> str | bytes | list[str] | list[bytes]:
         ''' Subclasses must override this method to return the contents of the output file for the given doc.
         subclassed methods return different types:
         str: html, json
