@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -99,6 +99,17 @@ with globs may not be expanded by the shell. In situations like this, the
 
     subprocess.call(["bokeh", "serve", "--glob", "*.py"])
 
+A .ico file may be configured with the ``--ico-path`` option, and the Bokeh
+server will return the contents of this file for ``/favicon.ico``:
+
+.. code-block:: sh
+
+    bokeh serve app.py --ico-path=/assets/app.ico
+
+Since browsers only look at the top-level root, only one .ico file may be
+supplied, even if multiple apps are running. By default, a Bokeh project logo
+is returned as the favicon.ico file.
+
 Application Configuration
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -388,7 +399,7 @@ Bokeh can also optionally log process memory usage. This feature requires
 the optional ``psutil`` package to be installed. To enable memory logging
 set the ``--mem-log-frequency`` option:
 
-. code-block:: sh
+.. code-block:: sh
 
     bokeh serve app_script.py --mem-log-frequency 30000
 
@@ -414,7 +425,7 @@ import argparse
 import os
 from fnmatch import fnmatch
 from glob import glob
-from typing import Any, Dict, List
+from typing import TYPE_CHECKING, Any
 
 # External imports
 from tornado.autoreload import watch
@@ -426,12 +437,15 @@ from bokeh.server.auth_provider import AuthModule, NullAuth
 from bokeh.server.tornado import DEFAULT_SESSION_TOKEN_EXPIRATION, DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES
 from bokeh.settings import settings
 from bokeh.util.logconfig import basicConfig
-from bokeh.util.string import format_docstring, nice_join
+from bokeh.util.strings import format_docstring, nice_join
 
 # Bokeh imports
 from ..subcommand import Argument, Subcommand
 from ..util import build_single_handler_applications, die, report_server_init_errors
 
+if TYPE_CHECKING:
+    from bokeh.server.server import Server
+
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -445,7 +459,7 @@ base_serve_args = (
         metavar = 'PORT',
         type    = int,
         help    = "Port to listen on",
-        default = DEFAULT_SERVER_PORT
+        default = DEFAULT_SERVER_PORT,
     )),
 
     ('--address', Argument(
@@ -455,11 +469,18 @@ base_serve_args = (
         default = None,
     )),
 
+    ('--unix-socket', Argument(
+        metavar = 'UNIX-SOCKET',
+        type    = str,
+        help    = "Unix socket to bind. Network options such as port, address, ssl options are incompatible with unix socket",
+        default = None,
+    )),
+
     ('--log-level', Argument(
         metavar = 'LOG-LEVEL',
         action  = 'store',
         default = None,
-        choices = LOGLEVELS + ("None", ),
+        choices = (*LOGLEVELS, 'None'),
         help    = "One of: %s" % nice_join(LOGLEVELS),
     )),
 
@@ -504,7 +525,9 @@ class Serve(Subcommand):
 
     help = "Run a Bokeh server hosting one or more applications"
 
-    args = base_serve_args + (
+    args = (
+        *base_serve_args,
+
         ('files', Argument(
             metavar = 'DIRECTORY-OR-SCRIPT',
             nargs   = '*',
@@ -548,7 +571,8 @@ class Serve(Subcommand):
             metavar = 'HOST[:PORT]',
             action  = 'append',
             type    = str,
-            help    = "Public hostnames which may connect to the Bokeh websocket",
+            help    = "Public hostnames which may connect to the Bokeh websocket "
+                      "With unix socket, the websocket origin restrictions should be enforced by the proxy.",
         )),
 
         ('--prefix', Argument(
@@ -558,6 +582,15 @@ class Serve(Subcommand):
             default = None,
         )),
 
+        ('--ico-path', Argument(
+            metavar = "ICO_PATH",
+            type    = str,
+            help    = "Path to a .ico file to use as the favicon.ico, or 'none' to "
+                      "disable favicon.ico support. If unset, a default Bokeh .ico "
+                      "file will be used",
+            default = None,
+        )),
+
         ('--keep-alive', Argument(
             metavar = 'MILLISECONDS',
             type    = int,
@@ -632,7 +665,7 @@ class Serve(Subcommand):
             default = False,
             help    = 'Whether to enable Tornado support for XSRF cookies. All '
                       'PUT, POST, or DELETE handlers must be properly instrumented '
-                      'when this setting is enabled.'
+                      'when this setting is enabled.',
         )),
 
         ('--exclude-headers', Argument(
@@ -640,7 +673,7 @@ class Serve(Subcommand):
             default = None,
             nargs='+',
             help    = 'A list of request headers to exclude from the session '
-                      'context (by default all headers are included).'
+                      'context (by default all headers are included).',
         )),
 
         ('--exclude-cookies', Argument(
@@ -648,7 +681,7 @@ class Serve(Subcommand):
             default = None,
             nargs='+',
             help    = 'A list of request cookies to exclude from the session '
-                      'context (by default all cookies are included).'
+                      'context (by default all cookies are included).',
         )),
 
         ('--include-headers', Argument(
@@ -656,7 +689,7 @@ class Serve(Subcommand):
             default = None,
             nargs='+',
             help    = 'A list of request headers to make available in the session '
-                      'context (by default all headers are included).'
+                      'context (by default all headers are included).',
         )),
 
         ('--include-cookies', Argument(
@@ -664,7 +697,7 @@ class Serve(Subcommand):
             default = None,
             nargs='+',
             help    = 'A list of request cookies to make available in the session '
-                      'context (by default all cookies are included).'
+                      'context (by default all cookies are included).',
         )),
 
         ('--cookie-secret', Argument(
@@ -742,20 +775,27 @@ class Serve(Subcommand):
         )),
     )
 
-    def customize_applications(self, args: argparse.Namespace, applications: Dict[str, Any]) -> Dict[str, Any]:
+    def customize_applications(self, args: argparse.Namespace, applications: dict[str, Any]) -> dict[str, Any]:
         '''Allows subclasses to customize ``applications``.
 
         Should modify and return a copy of the ``applications`` dictionary.
         '''
         return dict(applications)
 
-    def customize_kwargs(self, args: argparse.Namespace, server_kwargs: Dict[str, Any]) -> Dict[str, Any]:
+    def customize_kwargs(self, args: argparse.Namespace, server_kwargs: dict[str, Any]) -> dict[str, Any]:
         '''Allows subclasses to customize ``server_kwargs``.
 
         Should modify and return a copy of the ``server_kwargs`` dictionary.
         '''
         return dict(server_kwargs)
 
+    def customize_server(self, server: Server) -> Server:
+        '''Allows subclasses to customize the ``server``.
+
+        Should apply modifications to the server and wrap it or return the same instance.
+        '''
+        return server
+
     def invoke(self, args: argparse.Namespace) -> None:
         '''
 
@@ -778,7 +818,7 @@ class Serve(Subcommand):
         # even if Tornado is not installed
         from bokeh.server.server import Server
 
-        files: List[str] = []
+        files: list[str] = []
         for f in args.files:
             if args.glob:
                 files.extend(glob(f))
@@ -810,6 +850,7 @@ class Serve(Subcommand):
 
         server_kwargs = { key: getattr(args, key) for key in ['port',
                                                               'address',
+                                                              'unix_socket',
                                                               'allow_websocket_origin',
                                                               'num_procs',
                                                               'prefix',
@@ -855,6 +896,14 @@ class Serve(Subcommand):
             die("To sign sessions, the BOKEH_SECRET_KEY environment variable must be set; " +
                 "the `bokeh secret` command can be used to generate a new key.")
 
+        if 'unix_socket' in server_kwargs:
+            if server_kwargs['port'] != DEFAULT_SERVER_PORT:
+                die("--port arg is not supported with a unix socket")
+            invalid_args = ['address', 'ssl_certfile', 'ssl_keyfile']
+
+            if any(server_kwargs.get(x) for x in invalid_args):
+                die(f"{[*invalid_args, 'port']} args are not supported with a unix socket")
+
         auth_module_path = settings.auth_module(getattr(args, 'auth_module', None))
         if auth_module_path:
             server_kwargs['auth_provider'] = AuthModule(auth_module_path)
@@ -866,6 +915,7 @@ class Serve(Subcommand):
         server_kwargs['use_index'] = not args.disable_index
         server_kwargs['redirect_root'] = not args.disable_index_redirect
         server_kwargs['autoreload'] = args.dev is not None
+        server_kwargs['ico_path'] = settings.ico_path(getattr(args, 'ico_path', None))
 
         def find_autoreload_targets(app_path: str) -> None:
             path = os.path.abspath(app_path)
@@ -880,7 +930,7 @@ class Serve(Subcommand):
                         log.info("Watching: " + os.path.join(path, name))
                         watch(os.path.join(path, name))
 
-        def add_optional_autoreload_files(file_list: List[str]) -> None:
+        def add_optional_autoreload_files(file_list: list[str]) -> None:
             for filen in file_list:
                 if os.path.isdir(filen):
                     log.warning("Cannot watch directory " + filen)
@@ -913,20 +963,25 @@ class Serve(Subcommand):
 
                 server.io_loop.add_callback(show_callback)
 
-            address_string = 'localhost'
-            if server.address is not None and server.address != '':
-                address_string = server.address
+            # Server may not have a port when bound to a unix socket
+            if server.port:
+                address_string = 'localhost'
+                if server.address is not None and server.address != '':
+                    address_string = server.address
 
-            if server_kwargs['ssl_certfile'] and (server_kwargs['ssl_certfile'].endswith('.pem') or server_kwargs['ssl_keyfile']):
-                protocol = 'https'
-            else:
-                protocol = 'http'
+                if server_kwargs['ssl_certfile'] and (server_kwargs['ssl_certfile'].endswith('.pem') or server_kwargs['ssl_keyfile']):
+                    protocol = 'https'
+                else:
+                    protocol = 'http'
 
-            for route in sorted(applications.keys()):
-                url = f"{protocol}://{address_string}:{server.port}{server.prefix}{route}"
-                log.info("Bokeh app running at: %s" % url)
+                for route in sorted(applications.keys()):
+                    url = f"{protocol}://{address_string}:{server.port}{server.prefix}{route}"
+                    log.info("Bokeh app running at: %s" % url)
+
+                log.info("Starting Bokeh server with process id: %d" % os.getpid())
+
+            server = self.customize_server(server)
 
-            log.info("Starting Bokeh server with process id: %d" % os.getpid())
             server.run_until_shutdown()
 
 #-----------------------------------------------------------------------------
