@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -90,6 +90,7 @@ from ..util.strings import nice_join
 
 __all__ = (
     'Align',
+    'AlternationPolicy',
     'Anchor',
     'AngleUnits',
     'AutosizeMode',
@@ -114,6 +115,8 @@ __all__ = (
     'HorizontalLocation',
     'ImageOrigin',
     'JitterRandomDistribution',
+    'KeyModifier',
+    'LabelOrientation',
     'LatLon',
     'LegendClickPolicy',
     'LegendLocation',
@@ -144,7 +147,6 @@ __all__ = (
     'TextAlign',
     'TextBaseline',
     'TextureRepetition',
-    'TickLabelOrientation',
     'ToolIcon',
     'TooltipAttachment',
     'TooltipFieldFormatter',
@@ -255,6 +257,9 @@ HAlign = enumeration("top", "center", "bottom")
 #: Vertical alignment of a child item
 VAlign = enumeration("left", "center", "right")
 
+#: Specify to which items apply styling in a container (e.g. in a legend)
+AlternationPolicy = enumeration("none", "even", "odd", "every")
+
 #: Specify an anchor position on a box/frame
 Anchor = enumeration(
     "top_left",    "top_center",    "top_right",
@@ -370,6 +375,14 @@ ImageOrigin = enumeration("bottom_left", "top_left", "bottom_right", "top_right"
 JitterRandomDistributionType = Literal["uniform", "normal"]
 JitterRandomDistribution = enumeration(JitterRandomDistributionType)
 
+#:
+KeyModifier = Literal["shift", "ctrl", "alt"]
+KeyModifier = enumeration("shift", "ctrl", "alt")
+
+#: Specify how labels are oriented with respect to an axis
+LabelOrientationType = Literal["horizontal", "vertical", "parallel", "normal"]
+LabelOrientation = enumeration("horizontal", "vertical", "parallel", "normal")
+
 #: Specify whether a dimension or coordinate is latitude or longitude
 LatLon = enumeration("lat", "lon")
 
@@ -401,7 +414,7 @@ MarkerType = enumeration(
     "circle_y", "cross", "dash", "diamond", "diamond_cross", "diamond_dot",
     "dot", "hex", "hex_dot", "inverted_triangle", "plus", "square",
     "square_cross", "square_dot", "square_pin", "square_x", "star", "star_dot",
-    "triangle", "triangle_dot", "triangle_pin", "x", "y"
+    "triangle", "triangle_dot", "triangle_pin", "x", "y",
 )
 
 #: Specify one of the CSS4 named colors (https://www.w3.org/TR/css-color-4/#named-colors)
@@ -472,9 +485,6 @@ TextBaseline = enumeration("top", "middle", "bottom", "alphabetic", "hanging", "
 #: Specify how textures used as canvas patterns should repeat
 TextureRepetition = enumeration("repeat", "repeat_x", "repeat_y", "no_repeat")
 
-#: Specify how axis tick labels are oriented with respect to the axis
-TickLabelOrientation = enumeration("horizontal", "vertical", "parallel", "normal")
-
 #: Well known tool icon names
 ToolIcon = enumeration(
   "append_mode",
