@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -81,6 +81,7 @@ Basic Properties
 .. autoclass:: Bytes
 .. autoclass:: Color
 .. autoclass:: Complex
+.. autoclass:: CoordinateLike
 .. autoclass:: DashPattern
 .. autoclass:: Date
 .. autoclass:: Datetime
@@ -106,6 +107,7 @@ Basic Properties
 .. autoclass:: Size
 .. autoclass:: String
 .. autoclass:: Struct
+.. autoclass:: Time
 .. autoclass:: TimeDelta
 
 Container Properties
@@ -213,11 +215,13 @@ __all__ = (
     'ColorSpec',
     'ColumnData',
     'Complex',
+    'CoordinateLike',
     'DashPattern',
     'DashPatternSpec',
     'DataSpec',
     'Date',
     'Datetime',
+    'DeprecatedAlias',
     'Dict',
     'DistanceSpec',
     'Either',
@@ -276,6 +280,7 @@ __all__ = (
     'String',
     'StringSpec',
     'Struct',
+    'Time',
     'TimeDelta',
     'TextAlignSpec',
     'TextBaselineSpec',
@@ -294,7 +299,9 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-from .property.alias import Alias
+from .property.alias import Alias, DeprecatedAlias
+
+from .property.aliases import CoordinateLike
 
 from .property.any import Any
 from .property.any import AnyRef
@@ -341,6 +348,7 @@ from .property.dataspec import UnitsSpec
 
 from .property.datetime import Date
 from .property.datetime import Datetime
+from .property.datetime import Time
 from .property.datetime import TimeDelta
 
 from .property.descriptors import UnsetValueError
