@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,12 +21,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Type,
-)
+from typing import TYPE_CHECKING, Any, Callable
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -39,7 +34,7 @@ __all__ = (
     'type_link',
 )
 
-_type_links: dict[Type[Any], Callable[[Any], str]] = {}
+_type_links: dict[type[Any], Callable[[Any], str]] = {}
 
 #-----------------------------------------------------------------------------
 # General API
