@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -14,6 +14,8 @@ any validation.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging # isort:skip
 log = logging.getLogger(__name__)
 
@@ -21,23 +23,26 @@ log = logging.getLogger(__name__)
 # Imports
 #-----------------------------------------------------------------------------
 
+# Standard library imports
+import typing
+
 # Bokeh imports
-from .bases import Property
+from .bases import Init, Property
 
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
 
 __all__ = (
-    'Any',
-    'AnyRef'
+    "Any",
+    "AnyRef",
 )
 
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-class Any(Property):
+class Any(Property[typing.Any]):
     """ Accept all values.
 
     The ``Any`` property does not do any validation or transformation.
@@ -52,14 +57,6 @@ class Any(Property):
             used by the :ref:`bokeh.sphinxext.bokeh_prop` extension when
             generating Spinx documentation. (default: None)
 
-        serialized (bool, optional) :
-            Whether attributes created from this property should be included
-            in serialization (default: True)
-
-        readonly (bool, optional) :
-            Whether attributes created from this property are read-only.
-            (default: False)
-
     Example:
 
         .. code-block:: python
@@ -82,14 +79,15 @@ class Any(Property):
 
     """
 
-    def __init__(self, default=None, help=None, serialized=None, readonly=False):
-        super().__init__(default=default, help=help, serialized=serialized, readonly=readonly)
+    # TODO: default should be explicitly defined by the user (i.e. intrinsic here)
+    def __init__(self, default: Init[typing.Any] = None, help: str | None = None) -> None:
+        super().__init__(default=default, help=help)
 
 class AnyRef(Any):
     """ Accept all values and force reference discovery. """
 
     @property
-    def has_ref(self):
+    def has_ref(self) -> bool:
         return True
 
 #-----------------------------------------------------------------------------
