@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -33,7 +33,6 @@ from typing import (
     Any,
     Callable,
     ClassVar,
-    Type,
     TypeVar,
     Union,
 )
@@ -77,7 +76,7 @@ __all__ = (
 
 T = TypeVar("T")
 
-TypeOrInst: TypeAlias = Union[Type[T], T]
+TypeOrInst: TypeAlias = Union[type[T], T]
 
 Init: TypeAlias = Union[T, UndefinedType, IntrinsicType]
 
