@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -19,11 +19,18 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import Any
+from typing import Any, TypeVar, Union
 
 # Bokeh imports
+from ...util.deprecation import deprecated
 from ._sphinx import property_link, register_type_link, type_link
-from .bases import SingleParameterizedProperty
+from .bases import (
+    Init,
+    Property,
+    SingleParameterizedProperty,
+    TypeOrInst,
+)
+from .required import Required
 from .singletons import Undefined
 
 #-----------------------------------------------------------------------------
@@ -35,23 +42,22 @@ __all__ = (
     "Nullable",
 )
 
+T = TypeVar("T")
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-class Nullable(SingleParameterizedProperty):
+class Nullable(SingleParameterizedProperty[Union[T, None]]):
     """ A property accepting ``None`` or a value of some other type. """
 
-    def __init__(self, type_param, *, default=None, help=None, serialized=None, readonly=False) -> None:
-        super().__init__(type_param, default=default, help=help, serialized=serialized, readonly=readonly)
+    def __init__(self, type_param: TypeOrInst[Property[T]], *, default: Init[T | None] = None, help: str | None = None) -> None:
+        super().__init__(type_param, default=default, help=help)
 
-    def from_json(self, json, *, models=None):
-        return None if json is None else super().from_json(json, models=models)
-
-    def transform(self, value):
+    def transform(self, value: Any) -> T | None:
         return None if value is None else super().transform(value)
 
-    def wrap(self, value):
+    def wrap(self, value: Any) -> Any:
         return None if value is None else super().wrap(value)
 
     def validate(self, value: Any, detail: bool = True) -> None:
@@ -68,11 +74,18 @@ class Nullable(SingleParameterizedProperty):
         msg = "" if not detail else f"expected either None or a value of type {self.type_param}, got {value!r}"
         raise ValueError(msg)
 
-class NonNullable(SingleParameterizedProperty):
-    """ A property accepting a value of some other type while having undefined default. """
+class NonNullable(Required[T]):
+    """
+    A property accepting a value of some other type while having undefined default.
 
-    def __init__(self, type_param, *, default=Undefined, help=None, serialized=None, readonly=False) -> None:
-        super().__init__(type_param, default=default, help=help, serialized=serialized, readonly=readonly)
+    .. deprecated:: 3.0.0
+
+        Use ``bokeh.core.property.required.Required`` instead.
+    """
+
+    def __init__(self, type_param: TypeOrInst[Property[T]], *, default: Init[T] = Undefined, help: str | None = None) -> None:
+        deprecated((3, 0, 0), "NonNullable(Type)", "Required(Type)")
+        super().__init__(type_param, default=default, help=help)
 
 #-----------------------------------------------------------------------------
 # Dev API
@@ -88,5 +101,5 @@ class NonNullable(SingleParameterizedProperty):
 
 @register_type_link(Nullable)
 @register_type_link(NonNullable)
-def _sphinx_type_link(obj):
+def _sphinx_type_link(obj: SingleParameterizedProperty[Any]) -> str:
     return f"{property_link(obj)}({type_link(obj.type_param)})"
