@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -213,7 +213,8 @@ class MinMaxBounds(Either):
             Tuple(TimeDelta, Nullable(TimeDelta)),
         )
         if accept_datetime:
-            types = types + (
+            types = (
+                *types,
                 Tuple(Datetime, Datetime),
                 Tuple(Nullable(Datetime), Datetime),
                 Tuple(Datetime, Nullable(Datetime)),
