@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -30,7 +30,6 @@ from typing import (
     Callable,
     ClassVar,
     Generic,
-    List,
     Literal,
     NoReturn,
     Sequence,
@@ -60,6 +59,7 @@ from ..util.serialization import (
     transform_array,
     transform_series,
 )
+from ..util.warnings import BokehUserWarning, warn
 from .types import ID
 
 if TYPE_CHECKING:
@@ -109,7 +109,7 @@ class ArrayRep(TypedDict):
     type: Literal["array"]
     entries: NotRequired[list[AnyRep]]
 
-ArrayRepLike: TypeAlias = Union[ArrayRep, List[AnyRep]]
+ArrayRepLike: TypeAlias = Union[ArrayRep, list[AnyRep]]
 
 class SetRep(TypedDict):
     type: Literal["set"]
@@ -198,8 +198,10 @@ class Serializable:
 ObjID = int
 
 class Serializer:
-    """ Convert built-in and custom types into serializable representations. """
-
+    """ Convert built-in and custom types into serializable representations.
+        Not all built-in types are supported (e.g., decimal.Decimal due to
+        lacking support for fixed point arithmetic in JavaScript).
+    """
     _encoders: ClassVar[dict[type[Any], Encoder]] = {}
 
     @classmethod
@@ -283,7 +285,10 @@ class Serializer:
         elif isinstance(obj, TypedArray):
             return self._encode_typed_array(obj)
         elif isinstance(obj, np.ndarray):
-            return self._encode_ndarray(obj)
+            if obj.shape != ():
+                return self._encode_ndarray(obj)
+            else:
+                return self._encode(obj.item())
         elif is_dataclass(obj):
             return self._encode_dataclass(obj)
         else:
@@ -299,7 +304,7 @@ class Serializer:
         if -_MAX_SAFE_INT < obj <= _MAX_SAFE_INT:
             return obj
         else:
-            log.warning("out of range integer may result in loss of precision")
+            warn("out of range integer may result in loss of precision", BokehUserWarning)
             return self._encode_float(float(obj))
 
     def _encode_float(self, obj: float) -> NumberRep | float:
@@ -448,12 +453,14 @@ class Serializer:
         if np.issubdtype(type(obj), np.bool_):
             return self._encode_bool(bool(obj))
 
-        # avoid importing pandashere unless it is actually in use
+        # avoid importing pandas here unless it is actually in use
         module = type(obj).__module__
         if module is not None and module.startswith("pandas"):
             import pandas as pd
-            if isinstance(obj, (pd.Series, pd.Index)):
+            if isinstance(obj, (pd.Series, pd.Index, pd.api.extensions.ExtensionArray)):
                 return self._encode_ndarray(transform_series(obj))
+            elif obj is pd.NA:
+                return None
 
         self.error(f"can't serialize {type(obj)}")
 
@@ -463,6 +470,12 @@ class Serializer:
 class DeserializationError(ValueError):
     pass
 
+class UnknownReferenceError(DeserializationError):
+
+    def __init__(self, id: ID) -> None:
+        super().__init__(f"can't resolve reference '{id}'")
+        self.id = id
+
 class Deserializer:
     """ Convert from serializable representations to built-in and custom types. """
 
@@ -485,6 +498,9 @@ class Deserializer:
         self._decoding = False
         self._buffers = {}
 
+    def has_ref(self, obj: Model) -> bool:
+        return obj.id in self._references
+
     def deserialize(self, obj: Any | Serialized[Any]) -> Any:
         if isinstance(obj, Serialized):
             return self.decode(obj.content, obj.buffers)
@@ -555,7 +571,7 @@ class Deserializer:
         if instance is not None:
             return instance
         else:
-            self.error(f"can't resolve reference '{id}'")
+            self.error(UnknownReferenceError(id))
 
     def _decode_symbol(self, obj: SymbolRep) -> float:
         name = obj["name"]
@@ -659,7 +675,8 @@ class Deserializer:
         id = obj["id"]
         instance = self._references.get(id)
         if instance is not None:
-            self.error(f"reference already known '{id}'")
+            warn(f"reference already known '{id}'", BokehUserWarning)
+            return instance
 
         name = obj["name"]
         attributes = obj.get("attributes")
@@ -701,8 +718,11 @@ class Deserializer:
             else:
                 self.error(f"can't resolve type '{type}'")
 
-    def error(self, message: str) -> NoReturn:
-        raise DeserializationError(message)
+    def error(self, error: str | DeserializationError) -> NoReturn:
+        if isinstance(error, str):
+            raise DeserializationError(error)
+        else:
+            raise error
 
 #-----------------------------------------------------------------------------
 # Dev API
