@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -36,6 +36,7 @@ from ..events import (
     ModelEvent,
 )
 from ..model import Model
+from ..models.callbacks import Callback as JSEventCallback
 from ..util.callback_manager import _check_callback
 from .events import (
     DocumentPatchedEvent,
@@ -91,10 +92,11 @@ class DocumentCallbackManager:
 
     '''
 
-    _document : weakref.ReferenceType[Document]
+    _document: weakref.ReferenceType[Document]
 
     _change_callbacks: dict[Any, DocumentChangeCallback]
     _event_callbacks: dict[str, list[EventCallback]]
+    _js_event_callbacks: dict[str, list[JSEventCallback]]
     _message_callbacks: dict[str, list[MessageCallback]]
     _session_destroyed_callbacks: set[SessionDestroyedCallback]
     _session_callbacks: set[SessionCallback]
@@ -116,6 +118,7 @@ class DocumentCallbackManager:
 
         self._change_callbacks = {}
         self._event_callbacks = defaultdict(list)
+        self._js_event_callbacks = defaultdict(list)
         self._message_callbacks = defaultdict(list)
         self._session_destroyed_callbacks = set()
         self._session_callbacks = set()
@@ -199,6 +202,9 @@ class DocumentCallbackManager:
         self._event_callbacks.clear()
         del self._event_callbacks
 
+        self._js_event_callbacks.clear()
+        del self._js_event_callbacks
+
         self._message_callbacks.clear()
         del self._message_callbacks
 
@@ -273,6 +279,15 @@ class DocumentCallbackManager:
         ''' Provide callbacks to invoke if a bokeh event is received.
 
         '''
+        self._on_event(event, *callbacks)
+
+    def js_on_event(self, event: str | type[Event], *callbacks: JSEventCallback) -> None:
+        ''' Provide JS callbacks to invoke if a bokeh event is received.
+
+        '''
+        self._on_event(event, *callbacks)
+
+    def _on_event(self, event: str | type[Event], *callbacks: EventCallback | JSEventCallback) -> None:
         if not isinstance(event, str) and issubclass(event, Event):
             event = event.event_name
 
@@ -285,9 +300,11 @@ class DocumentCallbackManager:
                              "to a ModelEvent use the Model.on_event method.")
 
         for callback in callbacks:
-            _check_callback(callback, ('event',), what='Event callback')
-
-        self._event_callbacks[event].extend(callbacks)
+            if isinstance(callback, JSEventCallback):
+                self._js_event_callbacks[event].append(callback)
+            else:
+                _check_callback(callback, ('event',), what='Event callback')
+                self._event_callbacks[event].append(callback)
 
     def on_message(self, msg_type: str, *callbacks: MessageCallback) -> None:
         self._message_callbacks[msg_type].extend(callbacks)
