@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -46,7 +46,12 @@ from jinja2 import Template
 from ..core.enums import HoldPolicyType
 from ..core.has_props import is_DataModel
 from ..core.query import find, is_single_string_selector
-from ..core.serialization import Deserializer, Serialized, Serializer
+from ..core.serialization import (
+    Deserializer,
+    Serialized,
+    Serializer,
+    UnknownReferenceError,
+)
 from ..core.templates import FILE
 from ..core.types import ID
 from ..core.validation import check_integrity, process_validation_issues
@@ -60,6 +65,7 @@ from .callbacks import (
     Callback,
     DocumentCallbackManager,
     EventCallback,
+    JSEventCallback,
     MessageCallback,
 )
 from .events import (
@@ -112,8 +118,6 @@ class Document:
     models to JSON. Accordingly,  the ``Document`` is thus the smallest unit
     of serialization for Bokeh.
 
-    .. autoclasstoc::
-
     '''
 
     callbacks: DocumentCallbackManager
@@ -365,7 +369,19 @@ class Document:
 
         '''
         deserializer = Deserializer(list(self.models), setter=setter)
-        patch: PatchJson = deserializer.deserialize(patch_json)
+
+        try:
+            patch: PatchJson = deserializer.deserialize(patch_json)
+        except UnknownReferenceError as error:
+            if self.models.seen(error.id):
+                logging.warning(f"""\
+Dropping a patch because it contains a previously known reference (id={error.id!r}). \
+Most of the time this is harmless and usually a result of updating a model on one \
+side of a communications channel while it was being removed on the other end.\
+""")
+                return
+            else:
+                raise
 
         events = patch["events"]
         assert isinstance(events, list) # list[DocumentPatched]
@@ -374,6 +390,8 @@ class Document:
             # TODO: assert isinstance(event, DocumentPatchedEvent)
             DocumentPatchedEvent.handle_event(self, event, setter)
 
+        self.models.flush_synced(lambda model: not deserializer.has_ref(model))
+
     def clear(self) -> None:
         ''' Remove all content from the document but do not reset title.
 
@@ -530,6 +548,12 @@ class Document:
         '''
         self.callbacks.on_event(event, *callbacks)
 
+    def js_on_event(self, event: str | type[Event], *callbacks: JSEventCallback) -> None:
+        ''' Provide JS callbacks to invoke if a bokeh event is received.
+
+        '''
+        self.callbacks.js_on_event(event, *callbacks)
+
     def on_message(self, msg_type: str, *callbacks: MessageCallback) -> None:
         '''
 
@@ -726,15 +750,20 @@ class Document:
         serializer = Serializer(deferred=deferred)
         defs = serializer.encode(data_models)
         roots = serializer.encode(self._roots)
+        callbacks = serializer.encode(self.callbacks._js_event_callbacks)
 
         doc_json = DocJson(
             version=__version__,
             title=self.title,
-            defs=defs,
             roots=roots,
         )
 
-        self.models.flush()
+        if data_models:
+            doc_json["defs"] = defs
+        if self.callbacks._js_event_callbacks:
+            doc_json["callbacks"] = callbacks
+
+        self.models.flush_synced()
         return doc_json
 
     def unhold(self) -> None:
