@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -61,7 +61,6 @@ from typing import (
     Any,
     Callable,
     ClassVar,
-    List,
     Union,
     cast,
 )
@@ -120,7 +119,7 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 if TYPE_CHECKING:
-    Buffers: TypeAlias = Union[List[BufferRef], None]
+    Buffers: TypeAlias = Union[list[BufferRef], None]
 
     Invoker: TypeAlias = Callable[..., Any] # TODO
 
