@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -66,6 +66,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
+from datetime import datetime
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -82,6 +83,7 @@ if TYPE_CHECKING:
     from .model import Model
     from .models.plots import Plot
     from .models.widgets.buttons import AbstractButton
+    from .models.widgets.inputs import TextInput
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -89,12 +91,13 @@ if TYPE_CHECKING:
 
 __all__ = (
     'ButtonClick',
+    'ConnectionLost',
     'DocumentEvent',
     'DocumentReady',
     'DoubleTap',
     'Event',
-    'LODStart',
     'LODEnd',
+    'LODStart',
     'MenuItemClick',
     'ModelEvent',
     'MouseEnter',
@@ -107,17 +110,18 @@ __all__ = (
     'Pinch',
     'PinchEnd',
     'PinchStart',
-    'RangesUpdate',
-    'Rotate',
-    'RotateEnd',
-    'RotateStart',
     'PlotEvent',
     'PointEvent',
     'Press',
     'PressUp',
+    'RangesUpdate',
     'Reset',
+    'Rotate',
+    'RotateEnd',
+    'RotateStart',
     'SelectionGeometry',
     'Tap',
+    'ValueSubmit',
 )
 
 #-----------------------------------------------------------------------------
@@ -130,6 +134,11 @@ _CONCRETE_EVENT_CLASSES: dict[str, type[Event]] = {}
 # General API
 #-----------------------------------------------------------------------------
 
+class KeyModifiers(TypedDict):
+    shift: bool
+    ctrl: bool
+    alt: bool
+
 class EventRep(TypedDict):
     type: Literal["event"]
     name: str
@@ -143,6 +152,14 @@ class Event:
     '''
     event_name: ClassVar[str]
 
+    @staticmethod
+    def cls_for(event_name: str) -> type[Event]:
+        event_cls = _CONCRETE_EVENT_CLASSES.get(event_name)
+        if event_cls is not None:
+            return event_cls
+        else:
+            raise ValueError(f"unknown event name '{event_name}'")
+
     @classmethod
     def __init_subclass__(cls):
         super().__init_subclass__()
@@ -181,11 +198,48 @@ class DocumentEvent(Event):
 
 
 class DocumentReady(DocumentEvent):
-    ''' Announce when a Document is fully idle.
+    '''
+    Announce when a Document is fully idle.
+
+    .. note::
+        To register a JS callback for this event in standalone embedding
+        mode, one has to either use ``curdoc()`` or an explicit ``Document``
+        instance, e.g.:
+
+        .. code-block:: python
+
+            from bokeh.io import curdoc
+            curdoc().js_on_event("document_ready", handler)
 
     '''
     event_name = 'document_ready'
 
+class ConnectionEvent(DocumentEvent):
+    ''' Base class for connection status related events.
+
+    '''
+
+class ConnectionLost(ConnectionEvent):
+    '''
+    Announce when a connection to the server/client was lost.
+
+    .. note::
+        To register a JS callback for this event in standalone embedding
+        mode, one has to either use ``curdoc()`` or an explicit ``Document``
+        instance, e.g.:
+
+        .. code-block:: python
+
+            from bokeh.io import curdoc
+            curdoc().js_on_event("document_ready", handler)
+
+    '''
+    event_name = 'connection_lost'
+    timestamp: datetime
+
+    def __init__(self) -> None:
+        super().__init__()
+        self.timestamp = datetime.now()
 
 class ModelEvent(Event):
     ''' Base class for all Bokeh Model events.
@@ -230,6 +284,22 @@ class MenuItemClick(ModelEvent):
         self.item = item
         super().__init__(model=model)
 
+class ValueSubmit(ModelEvent):
+    ''' Announce a value being submitted on a text input widget.
+
+    '''
+    event_name = 'value_submit'
+
+    value: str
+
+    def __init__(self, model: TextInput | None, value: str) -> None:
+        from .models.widgets import TextInput
+        if model is not None and not isinstance(model, TextInput):
+            clsname = self.__class__.__name__
+            raise ValueError(f"{clsname} event only applies to text input models")
+        super().__init__(model=model)
+        self.value = value
+
 class PlotEvent(ModelEvent):
     ''' The base class for all events applicable to Plot models.
 
@@ -333,12 +403,20 @@ class PointEvent(PlotEvent):
     the HTML canvas.
 
     '''
-    def __init__(self, model: Plot | None, sx: float | None = None, sy:
-            float | None = None, x: float | None = None, y: float | None = None):
+    def __init__(
+        self,
+        model: Plot | None,
+        sx: float | None = None,
+        sy: float | None = None,
+        x: float | None = None,
+        y: float | None = None,
+        modifiers: KeyModifiers | None = None,
+    ):
         self.sx = sx
         self.sy = sy
         self.x = x
         self.y = y
+        self.modifiers = modifiers
         super().__init__(model=model)
 
 class Tap(PointEvent):
@@ -463,9 +541,10 @@ class MouseWheel(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.delta = delta
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class Pan(PointEvent):
     ''' Announce a pan event on a Bokeh plot.
@@ -491,11 +570,12 @@ class Pan(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.delta_x = delta_x
         self.delta_y = delta_y
         self.direction = direction
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class PanEnd(PointEvent):
     ''' Announce the end of a pan event on a Bokeh plot.
@@ -544,9 +624,10 @@ class Pinch(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.scale = scale
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class PinchEnd(PointEvent):
     ''' Announce the end of a pinch event on a Bokeh plot.
@@ -601,9 +682,10 @@ class Rotate(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.rotation = rotation
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class RotateEnd(PointEvent):
     ''' Announce the end of a rotate event on a Bokeh plot.
