@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -26,7 +26,6 @@ from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
-    List,
     Literal,
     Protocol,
     TypedDict,
@@ -328,7 +327,7 @@ def push_notebook(*, document: Document | None = None, state: State | None = Non
         return
 
     handle.doc.callbacks._held_events = []
-    msg = BokehProtocol().create("PATCH-DOC", cast(List["DocumentPatchedEvent"], events)) # XXX: either fix types or filter events
+    msg = BokehProtocol().create("PATCH-DOC", cast(list["DocumentPatchedEvent"], events)) # XXX: either fix types or filter events
 
     handle.comms.send(msg.header_json)
     handle.comms.send(msg.metadata_json)
@@ -377,7 +376,7 @@ def destroy_server(server_id: ID) -> None:
     '''
     server = curstate().uuid_to_server.get(server_id, None)
     if server is None:
-        log.debug("No server instance found for uuid: %r" % server_id)
+        log.debug(f"No server instance found for uuid: {server_id!r}")
         return
 
     try:
@@ -442,11 +441,14 @@ def load_notebook(resources: Resources | None = None, verbose: bool = False,
     from ..embed.bundle import bundle_for_objs_and_resources
     from ..resources import Resources
     from ..settings import settings
-    from ..util.serialization import make_id
+    from ..util.serialization import make_globally_unique_css_safe_id
 
     if resources is None:
         resources = Resources(mode=settings.resources())
 
+    element_id: ID | None
+    html: str | None
+
     if not hide_banner:
         if resources.mode == 'inline':
             js_info: str | list[str] = 'inline'
@@ -459,7 +461,7 @@ def load_notebook(resources: Resources | None = None, verbose: bool = False,
         if _NOTEBOOK_LOADED and verbose:
             warnings.append('Warning: BokehJS previously loaded')
 
-        element_id: ID | None = make_id()
+        element_id = make_globally_unique_css_safe_id()
 
         html = NOTEBOOK_LOAD.render(
             element_id    = element_id,
@@ -482,9 +484,10 @@ def load_notebook(resources: Resources | None = None, verbose: bool = False,
 
     if html is not None:
         publish_display_data({'text/html': html})
+
     publish_display_data({
-        JS_MIME_TYPE   : nb_js,
-        LOAD_MIME_TYPE : jl_js,
+        JS_MIME_TYPE:   nb_js,
+        LOAD_MIME_TYPE: jl_js,
     })
 
 def publish_display_data(data: dict[str, Any], metadata: dict[Any, Any] | None = None, *, transient: dict[str, Any] | None = None, **kwargs: Any) -> None:
@@ -553,17 +556,17 @@ def show_app(app: Application, state: State, notebook_url: str | Callable[[int |
     else:
         url = _server_url(notebook_url, server.port)
 
-    logging.debug("Server URL is %s" % url)
-    logging.debug("Origin URL is %s" % origin)
+    logging.debug(f"Server URL is {url}")
+    logging.debug(f"Origin URL is {origin}")
 
     from ..embed import server_document
     script = server_document(url, resources=None)
 
     publish_display_data({
         HTML_MIME_TYPE: script,
-        EXEC_MIME_TYPE: ""
+        EXEC_MIME_TYPE: "",
     }, metadata={
-        EXEC_MIME_TYPE: {"server_id": server_id}
+        EXEC_MIME_TYPE: {"server_id": server_id},
     })
 
 @overload
@@ -615,7 +618,7 @@ def _loading_js(bundle: Bundle, element_id: ID | None, load_timeout: int = 5000,
         elementid = element_id,
         force     = True,
         timeout   = load_timeout,
-        register_mime = register_mime
+        register_mime = register_mime,
     )
 
 def _origin_url(url: str) -> str:
