@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -85,7 +85,7 @@ def output_file(filename: PathLike, title: str = "Bokeh Plot",
         filename,
         title=title,
         mode=mode,
-        root_dir=root_dir
+        root_dir=root_dir,
     )
 
 def output_notebook(resources: Resources | None = None, verbose: bool = False,
