@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -53,7 +53,7 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 def save(obj: UIElement | Sequence[UIElement], filename: PathLike | None = None, resources: ResourcesLike | None = None,
-        title: str | None = None, template: Template | None = None, state: State | None = None) -> str:
+        title: str | None = None, template: Template | str | None = None, state: State | None = None) -> str:
     ''' Save an HTML file with the data for the current document.
 
     Will fall back to the default output state (or an explicitly provided
@@ -76,7 +76,7 @@ def save(obj: UIElement | Sequence[UIElement], filename: PathLike | None = None,
             If None, use the default state title value, if there is one.
             Otherwise, use "Bokeh Plot"
 
-        template (Template, optional) : HTML document template (default: FILE)
+        template (Template, str, optional) : HTML document template (default: FILE)
             A Jinja2 Template, see bokeh.core.templates.FILE for the required template
             parameters
 
@@ -156,12 +156,12 @@ def _get_save_title(state: State, title: str | None, suppress_warning: bool) ->
     return DEFAULT_TITLE
 
 def _save_helper(obj: UIElement | Sequence[UIElement], filename: PathLike, resources: Resources | None,
-        title: str | None, template: Template | None, theme: Theme | None = None) -> None:
+        title: str | None, template: Template | str | None, theme: Theme | None = None) -> None:
     '''
 
     '''
     from ..embed import file_html
-    html = file_html(obj, resources, title=title, template=template or FILE, theme=theme)
+    html = file_html(obj, resources=resources, title=title, template=template or FILE, theme=theme)
 
     with open(filename, mode="w", encoding="utf-8") as f:
         f.write(html)
