@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -43,7 +43,7 @@ if TYPE_CHECKING:
     from ..core.query import SelectorType
     from ..document import Document
     from ..document.events import DocumentPatchedEvent
-    from ..models.callbacks import Callback as JSEventCallback
+    from ..models.callbacks import Callback as JSEventCallback, CustomCode as JSChangeCallback
     from ..util.callback_manager import PropertyCallback
 
 #-----------------------------------------------------------------------------
@@ -255,7 +255,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
                 name=arg,
                 kind=Parameter.POSITIONAL_OR_KEYWORD,
                 # For positional arg properties, default=None means no default.
-                default=Parameter.empty if no_more_defaults else default
+                default=Parameter.empty if no_more_defaults else default,
             )
             if default:
                 del default
@@ -283,7 +283,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
             param = Parameter(
                 name=kw,
                 kind=Parameter.KEYWORD_ONLY,
-                default=default
+                default=default,
             )
             del default
             typ = type_link(descriptor.property)
@@ -302,19 +302,19 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
 
     def js_on_event(self, event: str | type[Event], *callbacks: JSEventCallback) -> None:
         if isinstance(event, str):
-            pass
+            event_name = Event.cls_for(event).event_name
         elif isinstance(event, type) and issubclass(event, Event):
-            event = event.event_name
+            event_name = event.event_name
         else:
             raise ValueError(f"expected string event name or event class, got {event}")
 
-        all_callbacks = list(self.js_event_callbacks.get(event, []))
+        all_callbacks = list(self.js_event_callbacks.get(event_name, []))
 
         for callback in callbacks:
             if callback not in all_callbacks:
                 all_callbacks.append(callback)
 
-        self.js_event_callbacks[event] = all_callbacks
+        self.js_event_callbacks[event_name] = all_callbacks
 
     def js_link(self, attr: str, other: Model, other_attr: str, attr_selector: int | str | None = None) -> None:
         ''' Link two Bokeh model properties using JavaScript.
@@ -382,14 +382,14 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
         '''
         descriptor = self.lookup(attr, raises=False)
         if descriptor is None:
-            raise ValueError("%r is not a property of self (%r)" % (attr, self))
+            raise ValueError(f"{attr!r} is not a property of self ({self!r})")
 
         if not isinstance(other, Model):
             raise ValueError("'other' is not a Bokeh model: %r" % other)
 
         other_descriptor = other.lookup(other_attr, raises=False)
         if other_descriptor is None:
-            raise ValueError("%r is not a property of other (%r)" % (other_attr, other))
+            raise ValueError(f"{other_attr!r} is not a property of other ({other!r})")
 
         from bokeh.models import CustomJS
 
@@ -398,7 +398,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
 
         self.js_on_change(attr, cb)
 
-    def js_on_change(self, event: str, *callbacks: JSEventCallback) -> None:
+    def js_on_change(self, event: str, *callbacks: JSChangeCallback) -> None:
         ''' Attach a :class:`~bokeh.models.CustomJS` callback to an arbitrary
         BokehJS model event.
 
@@ -427,9 +427,9 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
             raise ValueError("js_on_change takes an event name and one or more callbacks, got only one parameter")
 
         # handle any CustomJS callbacks here
-        from bokeh.models import CustomJS
-        if not all(isinstance(x, CustomJS) for x in callbacks):
-            raise ValueError("not all callback values are CustomJS instances")
+        from bokeh.models.callbacks import CustomCode
+        if not all(isinstance(x, CustomCode) for x in callbacks):
+            raise ValueError("not all callback values are CustomCode instances")
 
         descriptor = self.lookup(event, raises=False)
         if descriptor is not None:
@@ -454,7 +454,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
         Returns:
             None
 
-        Example:
+        Examples:
 
         .. code-block:: python
 
@@ -496,7 +496,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
         '''
         result = list(self.select(selector))
         if len(result) > 1:
-            raise ValueError("Found more than one object matching %s: %r" % (selector, result))
+            raise ValueError(f"Found more than one object matching {selector}: {result!r}")
         if len(result) == 0:
             return None
         return result[0]
