@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -51,9 +51,9 @@ from ..core.properties import (
     Enum,
     Float,
     Instance,
-    NonNullable,
     Nullable,
     NumberSpec,
+    Required,
     Seq,
     String,
     field,
@@ -94,7 +94,11 @@ class Expression(Model):
         the source changes, implement ``_v_compute: (source)`` instead.
 
     '''
-    pass
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 class CustomJSExpr(Expression):
     ''' Evaluate a JavaScript function/generator.
@@ -107,6 +111,10 @@ class CustomJSExpr(Expression):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     args = Dict(String, AnyRef, help="""
     A mapping of names to Python objects. In particular those can be bokeh's models.
     These objects are made available to the callback's code snippet as the values of
@@ -125,13 +133,18 @@ class CustomJSExpr(Expression):
     be collected into an array.
     """)
 
+
 class CumSum(Expression):
     ''' An expression for generating arrays by cumulatively summing a single
     column from a ``ColumnDataSource``.
 
     '''
 
-    field = NonNullable(String, help="""
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    field = Required(String, help="""
     The name of a ``ColumnDataSource`` column to cumulatively sum for new values.
     """)
 
@@ -153,6 +166,7 @@ class CumSum(Expression):
 
     """)
 
+
 class Stack(Expression):
     ''' An expression for generating arrays by summing different columns from
     a ``ColumnDataSource``.
@@ -162,6 +176,10 @@ class Stack(Expression):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     fields = Seq(String, default=[], help="""
     A sequence of fields from a ``ColumnDataSource`` to sum (elementwise). For
     example:
@@ -174,38 +192,46 @@ class Stack(Expression):
     of the ``'sales'`` and ``'marketing'`` columns of a data source.
     """)
 
+
 @abstract
 class ScalarExpression(Model):
     """ Base class for for scalar expressions. """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+
 class Minimum(ScalarExpression):
     """ Computes minimum value of a data source's column. """
 
-    field = NonNullable(String)
-    initial = Nullable(Float, default=None) # TODO: float("+inf"))
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    field = Required(String)
+    initial = Nullable(Float, default=float("+inf"))
+
 
 class Maximum(ScalarExpression):
     """ Computes maximum value of a data source's column. """
 
-    field = NonNullable(String)
-    initial = Nullable(Float, default=None) # TODO: float("-inf"))
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
 
-#-----------------------------------------------------------------------------
-# Dev API
-#-----------------------------------------------------------------------------
+    field = Required(String)
+    initial = Nullable(Float, default=float("-inf"))
 
-#-----------------------------------------------------------------------------
-# Private API
-#-----------------------------------------------------------------------------
-
-#-----------------------------------------------------------------------------
-# Code
-#-----------------------------------------------------------------------------
 
 @abstract
 class CoordinateTransform(Expression):
     """ Base class for coordinate transforms. """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     @property
     def x(self):
         return XComponent(transform=self)
@@ -214,9 +240,14 @@ class CoordinateTransform(Expression):
     def y(self):
         return YComponent(transform=self)
 
+
 class PolarTransform(CoordinateTransform):
     """ Transform from polar to cartesian coordinates. """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     radius = NumberSpec(default=field("radius"), help="""
     The radial coordinate (i.e. the distance from the origin).
 
@@ -232,14 +263,42 @@ class PolarTransform(CoordinateTransform):
     Whether ``angle`` measures clockwise or anti-clockwise from the reference axis.
     """)
 
+
 @abstract
 class XYComponent(Expression):
     """ Base class for bi-variate expressions. """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     transform = Instance(CoordinateTransform)
 
+
 class XComponent(XYComponent):
     """ X-component of a coordinate system transform to cartesian coordinates. """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+
 class YComponent(XYComponent):
     """ Y-component of a coordinate system transform to cartesian coordinates. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
