@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -38,22 +38,18 @@ log = logging.getLogger(__name__)
 
 # Bokeh imports
 from ..core.enums import (
-    Align,
-    Anchor,
     Direction,
-    HAlign,
     ImageOrigin,
     Palette,
     StepMode,
-    VAlign,
     enumeration,
 )
 from ..core.has_props import abstract
 from ..core.properties import (
     AngleSpec,
     Bool,
+    DataSpec,
     DistanceSpec,
-    Either,
     Enum,
     Float,
     Include,
@@ -64,13 +60,18 @@ from ..core.properties import (
     NullDistanceSpec,
     NumberSpec,
     Override,
-    Percent,
     Size,
     SizeSpec,
     String,
     StringSpec,
-    Tuple,
     field,
+    value,
+)
+from ..core.property_aliases import (
+    Anchor,
+    BorderRadius,
+    Padding,
+    TextAnchor,
 )
 from ..core.property_mixins import (
     FillProps,
@@ -91,7 +92,7 @@ from .glyph import (
     TextGlyph,
     XYGlyph,
 )
-from .mappers import ColorMapper, LinearColorMapper
+from .mappers import ColorMapper, LinearColorMapper, StackColorMapper
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -108,10 +109,14 @@ __all__ = (
     'Ellipse',
     'Glyph',
     'HArea',
+    'HAreaStep',
     'HBar',
+    'HSpan',
+    'HStrip',
     'HexTile',
     'Image',
     'ImageRGBA',
+    'ImageStack',
     'ImageURL',
     'Line',
     'Marker',
@@ -128,7 +133,10 @@ __all__ = (
     'Step',
     'Text',
     'VArea',
+    'VAreaStep',
     'VBar',
+    'VSpan',
+    'VStrip',
     'Wedge',
     'XYGlyph',
 )
@@ -192,6 +200,21 @@ class Marker(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
     The {prop} values for the markers.
     """)
 
+@abstract
+class LRTBGlyph(LineGlyph, FillGlyph, HatchGlyph):
+    """ Base class for axis-aligned rectangles. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    border_radius = BorderRadius(default=0, help="""
+    Allows the box to have rounded corners.
+
+    .. note::
+        This property is experimental and may change at any point.
+    """)
+
 class AnnularWedge(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
     ''' Render annular wedges.
 
@@ -380,7 +403,7 @@ class Bezier(LineGlyph):
     The {prop} values for the Bezier curves.
     """)
 
-class Block(LineGlyph, FillGlyph, HatchGlyph):
+class Block(LRTBGlyph):
     ''' Render rectangular regions, given a corner coordinate, width, and height.
 
     '''
@@ -541,7 +564,50 @@ class HArea(LineGlyph, FillGlyph, HatchGlyph):
     The {prop} values for the horizontal directed area.
     """)
 
-class HBar(LineGlyph, FillGlyph, HatchGlyph):
+class HAreaStep(FillGlyph, HatchGlyph):
+    ''' Render a horizontally directed area between two equal length sequences
+    of x-coordinates with the same y-coordinates using step lines.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/HAreaStep.py"
+
+    _args = ('x1', 'x2', 'y')
+
+    x1 = NumberSpec(default=field("x1"), help="""
+    The x-coordinates for the points of one side of the area.
+    """)
+
+    x2 = NumberSpec(default=field("x2"), help="""
+    The x-coordinates for the points of the other side of the area.
+    """)
+
+    y = NumberSpec(default=field("y"), help="""
+    The y-coordinates for the points of the area.
+    """)
+
+    step_mode = Enum(StepMode, default="before", help="""
+    Where the step "level" should be drawn in relation to the x and y
+    coordinates. The parameter can assume one of three values:
+
+    * ``before``: (default) Draw step levels before each y-coordinate (no step before the first point)
+    * ``after``:  Draw step levels after each y-coordinate (no step after the last point)
+    * ``center``: Draw step levels centered on each y-coordinate
+    """)
+
+    fill_props = Include(ScalarFillProps, help="""
+    The {prop} values for the horizontal directed area.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the horizontal directed area.
+    """)
+
+class HBar(LRTBGlyph):
     ''' Render horizontal bars, given a center coordinate, ``height`` and
     (``left``, ``right``) coordinates.
 
@@ -695,10 +761,7 @@ class ImageBase(XYGlyph):
     Defines the coordinate space of an image.
     """)
 
-    anchor = Either(
-        Enum(Anchor),
-        Tuple(Either(Enum(Align), Enum(HAlign), Percent),
-              Either(Enum(Align), Enum(VAlign), Percent)), default="bottom_left", help="""
+    anchor = Anchor(default="bottom_left", help="""
     Position of the image should be anchored at the `x`, `y` coordinates.
     """)
 
@@ -734,8 +797,8 @@ class Image(ImageBase):
     _extra_kws = {
         'palette': (
             'str or list[color value]',
-            'a palette to construct a value for the color mapper property from'
-        )
+            'a palette to construct a value for the color mapper property from',
+        ),
     }
 
     image = NumberSpec(default=field("image"), help="""
@@ -768,6 +831,34 @@ class ImageRGBA(ImageBase):
     The arrays of RGBA data for the images.
     """)
 
+class ImageStack(ImageBase):
+    ''' Render images given as 3D stacked arrays by flattening each stack into
+    an RGBA image using a ``StackColorMapper``.
+
+    The 3D arrays have shape (ny, nx, nstack) where ``nstack` is the number of
+    stacks. The ``color_mapper`` produces an RGBA value for each of the
+    (ny, nx) pixels by combining array values in the ``nstack`` direction.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    _args = ('image', 'x', 'y', 'dw', 'dh', 'dilate')
+
+    image = NumberSpec(default=field("image"), help="""
+    The 3D arrays of data for the images.
+    """)
+
+    color_mapper = Instance(StackColorMapper, help="""
+    ``ScalarColorMapper`` used to map the scalar data from ``image``
+    into RGBA values for display.
+
+    .. note::
+        The color mapping step happens on the client.
+    """)
+
 class ImageURL(XYGlyph):
     ''' Render images loaded from given URLs.
 
@@ -828,7 +919,7 @@ class ImageURL(XYGlyph):
     images to have a gap between them, when they should appear flush.
     """)
 
-    anchor = Enum(Anchor, default="top_left", help="""
+    anchor = Anchor(default="top_left", help="""
     Position of the image should be anchored at the `x`, `y` coordinates.
     """)
 
@@ -1049,7 +1140,7 @@ class Patches(LineGlyph, FillGlyph, HatchGlyph):
     The {prop} values for the patches.
     """)
 
-class Quad(LineGlyph, FillGlyph, HatchGlyph):
+class Quad(LRTBGlyph):
     ''' Render axis-aligned quads.
 
     '''
@@ -1166,7 +1257,13 @@ class Ray(XYGlyph, LineGlyph):
     """)
 
 class Rect(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
-    ''' Render rectangles.
+    ''' Render rectangles, characterised by center position (x and y), width,
+    height, and angle of rotation.
+
+    .. warning::
+        ``Rect`` glyphs are not well defined on logarithmic scales. Use
+        :class:`~bokeh.models.Block` or :class:`~bokeh.models.Quad` glyphs
+        instead.
 
     '''
 
@@ -1198,6 +1295,13 @@ class Rect(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
     The angles to rotate the rectangles, as measured from the horizontal.
     """)
 
+    border_radius = BorderRadius(default=0, help="""
+    Allows the box to have rounded corners.
+
+    .. note::
+        This property is experimental and may change at any point.
+    """)
+
     dilate = Bool(False, help="""
     Whether to always round fractional pixel locations in such a way
     as to make the rectangles bigger.
@@ -1380,7 +1484,7 @@ class Text(XYGlyph, TextGlyph):
     The y-coordinates to locate the text anchors.
     """)
 
-    text = StringSpec("text", help="""
+    text = StringSpec(default=field("text"), help="""
     The text values to render.
     """)
 
@@ -1389,23 +1493,68 @@ class Text(XYGlyph, TextGlyph):
     """)
 
     x_offset = NumberSpec(default=0, help="""
-    Offset values to apply to the x-coordinates.
+    Offset values in pixels to apply to the x-coordinates.
 
     This is useful, for instance, if it is desired to "float" text a fixed
     distance in |screen units| from a given data position.
     """)
 
     y_offset = NumberSpec(default=0, help="""
-    Offset values to apply to the y-coordinates.
+    Offset values in pixels to apply to the y-coordinates.
 
     This is useful, for instance, if it is desired to "float" text a fixed
     distance in |screen units| from a given data position.
     """)
 
+    anchor = DataSpec(TextAnchor, default=value("auto"), help="""
+    Position within the bounding box of this glyph to which ``x`` and ``y``
+    coordinates are anchored to. This can be a named anchor point like
+    ``top_left`` or ``center``, or a percentage from from left to right
+    and top to bottom, or a combination of those, independently in width
+    and height. If set to ``auto``, then anchor point will be determined
+    from text ``align`` and ``baseline``.
+
+    .. note::
+        This property is experimental and may change at any point.
+    """)
+
+    padding = Padding(default=0, help="""
+    Extra space between the text of a glyphs and its bounding box (border).
+
+    .. note::
+        This property is experimental and may change at any point.
+    """)
+
+    border_radius = BorderRadius(default=0, help="""
+    Allows the box to have rounded corners. For the best results, it
+    should be used in combination with ``padding``.
+
+    .. note::
+        This property is experimental and may change at any point.
+    """)
+
     text_props = Include(TextProps, help="""
     The {prop} values for the text.
     """)
 
+    background_fill_props = Include(FillProps, prefix="background", help="""
+    The {prop} values for the text bounding box.
+    """)
+
+    background_hatch_props = Include(HatchProps, prefix="background", help="""
+    The {prop} values for the text bounding box.
+    """)
+
+    border_line_props = Include(LineProps, prefix="border", help="""
+    The {prop} values for the text bounding box.
+    """)
+
+    background_fill_color = Override(default=None)
+
+    background_hatch_color = Override(default=None)
+
+    border_line_color = Override(default=None)
+
 class VArea(FillGlyph, HatchGlyph):
     ''' Render a vertically directed area between two equal length sequences
     of y-coordinates with the same x-coordinates.
@@ -1440,7 +1589,50 @@ class VArea(FillGlyph, HatchGlyph):
     The {prop} values for the vertical directed area.
     """)
 
-class VBar(LineGlyph, FillGlyph, HatchGlyph):
+class VAreaStep(FillGlyph, HatchGlyph):
+    ''' Render a vertically directed area between two equal length sequences
+    of y-coordinates with the same x-coordinates using step lines.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/VAreaStep.py"
+
+    _args = ('x', 'y1', 'y2')
+
+    x = NumberSpec(default=field("x"), help="""
+    The x-coordinates for the points of the area.
+    """)
+
+    y1 = NumberSpec(default=field("y1"), help="""
+    The y-coordinates for the points of one side of the area.
+    """)
+
+    y2 = NumberSpec(default=field("y2"), help="""
+    The y-coordinates for the points of the other side of the area.
+    """)
+
+    step_mode = Enum(StepMode, default="before", help="""
+    Where the step "level" should be drawn in relation to the x and y
+    coordinates. The parameter can assume one of three values:
+
+    * ``before``: (default) Draw step levels before each x-coordinate (no step before the first point)
+    * ``after``:  Draw step levels after each x-coordinate (no step after the last point)
+    * ``center``: Draw step levels centered on each x-coordinate
+    """)
+
+    fill_props = Include(ScalarFillProps, help="""
+    The {prop} values for the vertical directed area.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the vertical directed area.
+    """)
+
+class VBar(LRTBGlyph):
     ''' Render vertical bars, given a center coordinate, width and (top, bottom) coordinates.
 
     '''
@@ -1530,6 +1722,106 @@ class Wedge(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
     The {prop} values for the wedges.
     """)
 
+class HSpan(LineGlyph):
+    """ Horizontal lines of infinite width. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/HSpan.py"
+
+    _args = ("y")
+
+    y = NumberSpec(default=field("y"), help="""
+    The y-coordinates of the spans.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the spans.
+    """)
+
+class VSpan(LineGlyph):
+    """ Vertical lines of infinite height. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/VSpan.py"
+
+    _args = ("x")
+
+    x = NumberSpec(default=field("x"), help="""
+    The x-coordinates of the spans.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the spans.
+    """)
+
+class HStrip(LineGlyph, FillGlyph, HatchGlyph):
+    """ Horizontal strips of infinite width. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/HStrip.py"
+
+    _args = ("y0", "y1")
+
+    y0 = NumberSpec(default=field("y0"), help="""
+    The y-coordinates of the coordinates of one side of the strips.
+    """)
+
+    y1 = NumberSpec(default=field("y1"), help="""
+    The y-coordinates of the coordinates of the other side of the strips.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    fill_props = Include(FillProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the strips.
+    """)
+
+class VStrip(LineGlyph, FillGlyph, HatchGlyph):
+    """ Vertical strips of infinite height. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/VStrip.py"
+
+    _args = ("x0", "x1")
+
+    x0 = NumberSpec(default=field("x0"), help="""
+    The x-coordinates of the coordinates of one side of the strips.
+    """)
+
+    x1 = NumberSpec(default=field("x1"), help="""
+    The x-coordinates of the coordinates of the other side of the strips.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    fill_props = Include(FillProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the strips.
+    """)
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
