@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,11 +22,9 @@ from ..core.has_props import abstract
 from ..core.properties import (
     Any,
     Dict,
-    Either,
     Instance,
     Int,
     Seq,
-    String,
 )
 from ..model import Model
 from .expressions import CoordinateTransform
@@ -43,6 +41,7 @@ __all__ = (
     'GraphHitTestPolicy',
     'LayoutProvider',
     'NodeCoordinates',
+    'NodesAndAdjacentNodes',
     'NodesAndLinkedEdges',
     'NodesOnly',
     'StaticLayoutProvider',
@@ -62,6 +61,10 @@ class LayoutProvider(Model):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     @property
     def node_coordinates(self) -> NodeCoordinates:
         return NodeCoordinates(layout=self)
@@ -75,7 +78,12 @@ class StaticLayoutProvider(LayoutProvider):
 
     '''
 
-    graph_layout = Dict(Either(String, Int), Seq(Any), default={}, help="""
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    # TODO: Seq(Any).length == 2
+    graph_layout = Dict(Int, Seq(Any), default={}, help="""
     The coordinates of the graph nodes in cartesian space. The dictionary
     keys correspond to a node index and the values are a two element sequence
     containing the x and y coordinates of the node.
@@ -95,6 +103,11 @@ class GraphCoordinates(CoordinateTransform):
     Abstract class for coordinate transform expression obtained from ``LayoutProvider``
 
     '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     layout = Instance(LayoutProvider)
 
 class NodeCoordinates(GraphCoordinates):
@@ -103,7 +116,10 @@ class NodeCoordinates(GraphCoordinates):
 
     '''
 
-    pass
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 class EdgeCoordinates(GraphCoordinates):
     '''
@@ -111,7 +127,10 @@ class EdgeCoordinates(GraphCoordinates):
 
     '''
 
-    pass
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 @abstract
 class GraphHitTestPolicy(Model):
@@ -119,7 +138,10 @@ class GraphHitTestPolicy(Model):
 
     '''
 
-    pass
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 class EdgesOnly(GraphHitTestPolicy):
     '''
@@ -128,7 +150,10 @@ class EdgesOnly(GraphHitTestPolicy):
 
     '''
 
-    pass
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 class NodesOnly(GraphHitTestPolicy):
     '''
@@ -137,7 +162,10 @@ class NodesOnly(GraphHitTestPolicy):
 
     '''
 
-    pass
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 class NodesAndLinkedEdges(GraphHitTestPolicy):
     '''
@@ -148,7 +176,10 @@ class NodesAndLinkedEdges(GraphHitTestPolicy):
 
     '''
 
-    pass
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 class EdgesAndLinkedNodes(GraphHitTestPolicy):
     '''
@@ -159,7 +190,25 @@ class EdgesAndLinkedNodes(GraphHitTestPolicy):
 
     '''
 
-    pass
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+
+class NodesAndAdjacentNodes(GraphHitTestPolicy):
+    '''
+    With the ``NodesAndAdjacentNodes`` policy, inspection or selection of
+    graph nodes will also result in the inspection or selection any nodes that
+    are immediately adjacent (connected by a single edge). There is no
+    selection or inspection of graph edges, and no indication of which node is
+    the tool-selected one from the policy-selected nodes.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 #-----------------------------------------------------------------------------
 # Private API
@@ -168,10 +217,3 @@ class EdgesAndLinkedNodes(GraphHitTestPolicy):
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
-
-# TODO (bev) deprecation: 3.0
-def from_networkx(graph, layout_function, **kwargs):
-    from bokeh.plotting import from_networkx as real_from_networkx
-    from bokeh.util.deprecation import deprecated
-    deprecated("Importing from_networkx from bokeh.models.graphs is deprecated and will be removed in Bokeh 3.0. Import from bokeh.plotting instead")
-    return real_from_networkx(graph, layout_function, **kwargs)
