@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,32 +21,35 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Bokeh imports
+from ..colors import RGB, Color, ColorLike
 from ..core.enums import (
     Align,
+    Dimensions,
+    FlowMode,
     Location,
+    ScrollbarPolicy,
     SizingMode,
     SizingPolicy,
 )
-from ..core.has_props import abstract
+from ..core.has_props import HasProps, abstract
 from ..core.properties import (
     Auto,
     Bool,
-    Color,
-    Dict,
     Either,
     Enum,
     Float,
     Instance,
     Int,
     List,
-    NonNegativeInt,
+    NonNegative,
     Null,
     Nullable,
-    Seq,
     String,
     Struct,
     Tuple,
 )
+from ..core.property.struct import Optional
+from ..core.property_aliases import GridSpacing, Pixels, TracksSizing
 from ..core.validation import error, warning
 from ..core.validation.errors import MIN_PREFERRED_MAX_HEIGHT, MIN_PREFERRED_MAX_WIDTH, REPEATED_LAYOUT_CHILD
 from ..core.validation.warnings import (
@@ -57,22 +60,26 @@ from ..core.validation.warnings import (
     FIXED_WIDTH_POLICY,
 )
 from ..model import Model
+from .ui.menus import Menu
+from .ui.ui_element import UIElement
 
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
 
 __all__ = (
-    'Box',
     'Column',
+    'FlexBox',
     'GridBox',
-    'HTMLBox',
+    'GroupBox',
+    'HBox',
     'LayoutDOM',
-    'Panel',
     'Row',
+    'ScrollBox',
     'Spacer',
+    'TabPanel',
     'Tabs',
-    'WidgetBox',
+    'VBox',
 )
 
 #-----------------------------------------------------------------------------
@@ -80,56 +87,55 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 @abstract
-class LayoutDOM(Model):
+class LayoutDOM(UIElement):
     """ The base class for layoutable components.
 
     """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     disabled = Bool(False, help="""
     Whether the widget will be disabled when rendered.
 
     If ``True``, the widget will be greyed-out and not responsive to UI events.
     """)
 
-    visible = Bool(True, help="""
-    Whether the component will be visible and a part of a layout.
-    """)
-
-    width: int | None = Nullable(NonNegativeInt, help="""
+    width: int | None = Nullable(NonNegative(Int), help="""
     The width of the component (in pixels).
 
     This can be either fixed or preferred width, depending on width sizing policy.
     """)
 
-    height: int | None = Nullable(NonNegativeInt, help="""
+    height: int | None = Nullable(NonNegative(Int), help="""
     The height of the component (in pixels).
 
     This can be either fixed or preferred height, depending on height sizing policy.
     """)
 
-    min_width = Nullable(NonNegativeInt, help="""
+    min_width = Nullable(NonNegative(Int), help="""
     Minimal width of the component (in pixels) if width is adjustable.
     """)
 
-    min_height = Nullable(NonNegativeInt, help="""
+    min_height = Nullable(NonNegative(Int), help="""
     Minimal height of the component (in pixels) if height is adjustable.
     """)
 
-    max_width = Nullable(NonNegativeInt, help="""
+    max_width = Nullable(NonNegative(Int), help="""
     Maximal width of the component (in pixels) if width is adjustable.
     """)
 
-    max_height = Nullable(NonNegativeInt, help="""
+    max_height = Nullable(NonNegative(Int), help="""
     Maximal height of the component (in pixels) if height is adjustable.
     """)
 
-    margin = Nullable(Tuple(Int, Int, Int, Int), default=(0, 0, 0, 0), help="""
+    margin = Nullable(Either(Int, Tuple(Int, Int), Tuple(Int, Int, Int, Int)), help="""
     Allows to create additional space around the component.
     The values in the tuple are ordered as follows - Margin-Top, Margin-Right, Margin-Bottom and Margin-Left,
     similar to CSS standards.
     Negative margin values may be used to shrink the space from any direction.
-    """).accepts(Tuple(Int, Int), lambda v_h: (v_h[0], v_h[1], v_h[0], v_h[1])) \
-        .accepts(Int, lambda m: (m, m, m, m))
+    """)
 
     width_policy = Either(Auto, Enum(SizingPolicy), default="auto", help="""
     Describes how the component should maintain its width.
@@ -205,6 +211,10 @@ class LayoutDOM(Model):
 
     """)
 
+    flow_mode = Enum(FlowMode, default="block", help="""
+    Defines whether the layout will flow in the ``block`` or ``inline`` dimension.
+    """)
+
     sizing_mode = Nullable(Enum(SizingMode), help="""
     How the component should size itself.
 
@@ -214,6 +224,11 @@ class LayoutDOM(Model):
 
     Possible scenarios:
 
+    ``"inherit"``
+        The sizing mode is inherited from the parent layout. If there is no parent
+        layout (or parent is not a layout), then this value is treated as if no
+        value for ``sizing_mode`` was provided.
+
     ``"fixed"``
         Component is not responsive. It will retain its original width and height
         regardless of any subsequent browser window resize events.
@@ -247,7 +262,7 @@ class LayoutDOM(Model):
 
     """)
 
-    align = Either(Enum(Align), Tuple(Enum(Align), Enum(Align)), default="start", help="""
+    align = Either(Auto, Enum(Align), Tuple(Enum(Align), Enum(Align)), default="auto", help="""
     The alignment point within the parent container.
 
     This property is useful only if this component is a child element of a layout
@@ -255,18 +270,32 @@ class LayoutDOM(Model):
     grid track align).
     """)
 
-    background = Nullable(Color, help="""
-    Background color of the component.
+    context_menu = Nullable(Instance(Menu), default=None, help="""
+    A menu to display when user right clicks on the component.
+
+    .. note::
+        To display a native context menu, the viewer will need to right-click
+        twice. The second click closes the Bokeh context menu and falls back
+        back the native one.
     """)
 
-    # List in order for in-place changes to trigger changes, ref: https://github.com/bokeh/bokeh/issues/6841
-    css_classes = List(String, help="""
-    A list of CSS class names to add to this DOM element. Note: the class names are
-    simply added as-is, no other guarantees are provided.
+    resizable = Either(Bool, Enum(Dimensions), default=False, help="""
+    Whether the layout is interactively resizable, and if so in which dimensions.
+    """)
 
-    It is also permissible to assign from tuples, however these are adapted -- the
-    property will always contain a list.
-    """).accepts(Seq(String), lambda x: list(x))
+    def _set_background(self, color: ColorLike) -> None:
+        """ Background color of the component. """
+        if isinstance(color, Color):
+            color = color.to_css()
+        elif isinstance(color, tuple):
+            color = RGB.from_tuple(color).to_css()
+
+        if isinstance(self.styles, dict):
+            self.styles["background-color"] = color
+        else:
+            self.styles.background_color = color
+
+    background = property(None, _set_background)
 
     @warning(FIXED_SIZING_MODE)
     def _check_fixed_sizing_mode(self):
@@ -306,62 +335,58 @@ class LayoutDOM(Model):
             return self.height
         return None
 
-@abstract
-class HTMLBox(LayoutDOM):
-    ''' A component which size is determined by its HTML content.
-
-    '''
-
 class Spacer(LayoutDOM):
     ''' A container for space used to fill an empty spot in a row or column.
 
     '''
 
-QuickTrackSizing = Either(Enum("auto", "min", "fit", "max"), Int)
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
 
-TrackAlign = Either(Auto, Enum(Align))
+@abstract
+class GridCommon(HasProps):
+    """ Common properties for grid-like layouts. """
 
-RowSizing = Either(
-    QuickTrackSizing,
-    Struct(policy=Enum("auto", "min"), align=TrackAlign),
-    Struct(policy=Enum("fixed"), height=Int, align=TrackAlign),
-    Struct(policy=Enum("fit", "max"), flex=Float, align=TrackAlign))
-
-ColSizing = Either(
-    QuickTrackSizing,
-    Struct(policy=Enum("auto", "min"), align=TrackAlign),
-    Struct(policy=Enum("fixed"), width=Int, align=TrackAlign),
-    Struct(policy=Enum("fit", "max"), flex=Float, align=TrackAlign))
-
-IntOrString = Either(Int, String) # XXX: work around issue #8166
-
-class GridBox(LayoutDOM):
-
-    children = List(Either(
-        Tuple(Instance(LayoutDOM), Int, Int),
-        Tuple(Instance(LayoutDOM), Int, Int, Int, Int)), default=[], help="""
-    A list of children with their associated position in the grid (row, column).
-    """)
-
-    rows = Either(QuickTrackSizing, Dict(IntOrString, RowSizing), default="auto", help="""
+    rows = Nullable(TracksSizing, default=None, help="""
     Describes how the grid should maintain its rows' heights.
 
-    .. note::
-        This is an experimental feature and may change in future. Use it at your
-        own discretion.
+    This maps to CSS grid's track sizing options. In particular the following
+    values are allowed:
 
+    * length, e.g. ``100px``, ``5.5em``
+    * percentage, e.g. ``33%``
+    * flex, e.g. 1fr
+    * enums, e.g.  ``max-content``, ``min-content``, ``auto``, etc.
+
+    If a single value is provided, then it applies to all rows. A list of
+    values can be provided to size all rows, or a dictionary providing
+    sizing for individual rows.
+
+    See https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-rows
+    or https://w3c.github.io/csswg-drafts/css-grid/#track-sizing for details.
     """)
 
-    cols = Either(QuickTrackSizing, Dict(IntOrString, ColSizing), default="auto", help="""
+    cols = Nullable(TracksSizing, default=None, help="""
     Describes how the grid should maintain its columns' widths.
 
-    .. note::
-        This is an experimental feature and may change in future. Use it at your
-        own discretion.
+    This maps to CSS grid's track sizing options. In particular the following
+    values are allowed:
 
+    * length, e.g. ``100px``, ``5.5em``
+    * percentage, e.g. ``33%``
+    * flex, e.g. 1fr
+    * enums, e.g.  ``max-content``, ``min-content``, ``auto``, etc.
+
+    If a single value is provided, then it applies to all columns. A list of
+    values can be provided to size all columns, or a dictionary providing
+    sizing for individual columns.
+
+    See https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-columns
+    or https://w3c.github.io/csswg-drafts/css-grid/#track-sizing for details.
     """)
 
-    spacing = Either(Int, Tuple(Int, Int), default=0, help="""
+    spacing = GridSpacing(default=0, help="""
     The gap between children (in pixels).
 
     Either a number, if spacing is the same for both dimensions, or a pair
@@ -369,14 +394,77 @@ class GridBox(LayoutDOM):
     respectively.
     """)
 
+class GridBox(LayoutDOM, GridCommon):
+    """ A CSS grid-based grid container. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    children = List(Either(
+        Tuple(Instance(UIElement), Int, Int),
+        Tuple(Instance(UIElement), Int, Int, Int, Int)), default=[], help="""
+    A list of children with their associated position in the grid (row, column).
+    """)
+
     @error(REPEATED_LAYOUT_CHILD)
     def _check_repeated_layout_children(self):
         children = [ child[0] for child in self.children ]
         if len(children) != len(set(children)):
             return str(self)
 
+class HBox(LayoutDOM):
+    """ A CSS grid-based horizontal box. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    children = List(Struct(child=Instance(UIElement), col=Optional(Int), span=Optional(Int)), default=[], help="""
+    A list of children with their associated position in the horizontal box (optional; column number, span).
+    """).accepts(List(Instance(UIElement)), lambda children: [ dict(child=child) for child in children ])
+
+    cols = Nullable(TracksSizing, default=None, help="""
+    Describes how the grid should maintain its columns' widths.
+    """)
+
+    spacing = Pixels(default=0, help="""
+    The gap between children (in pixels).
+    """)
+
+    @error(REPEATED_LAYOUT_CHILD)
+    def _check_repeated_layout_children(self):
+        children = [ item["child"] for item in self.items ]
+        if len(children) != len(set(children)):
+            return str(self)
+
+class VBox(LayoutDOM):
+    """ A CSS grid-based vertical box. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    children = List(Struct(child=Instance(UIElement), row=Optional(Int), span=Optional(Int)), default=[], help="""
+    A list of children with their associated position in the vertical box (optional; row number, span).
+    """).accepts(List(Instance(UIElement)), lambda children: [ dict(child=child) for child in children ])
+
+    rows = Nullable(TracksSizing, default=None, help="""
+    Describes how the grid should maintain its rows' heights.
+    """)
+
+    spacing = Pixels(default=0, help="""
+    The gap between children (in pixels).
+    """)
+
+    @error(REPEATED_LAYOUT_CHILD)
+    def _check_repeated_layout_children(self):
+        children = [ item["child"] for item in self.items ]
+        if len(children) != len(set(children)):
+            return str(self)
+
 @abstract
-class Box(LayoutDOM):
+class FlexBox(LayoutDOM):
     ''' Abstract base class for Row and Column. Do not use directly.
 
     '''
@@ -412,7 +500,7 @@ class Box(LayoutDOM):
         if len(self.children) != len(set(self.children)):
             return str(self)
 
-    children = List(Instance(LayoutDOM), help="""
+    children = List(Instance(UIElement), help="""
     The list of children, which can be other components including plots, rows, columns, and widgets.
     """)
 
@@ -421,58 +509,52 @@ class Box(LayoutDOM):
     """)
 
 
-class Row(Box):
+class Row(FlexBox):
     ''' Lay out child components in a single horizontal row.
 
     Children can be specified as positional arguments, as a single argument
     that is a sequence, or using the ``children`` keyword argument.
     '''
 
-    cols = Either(QuickTrackSizing, Dict(IntOrString, ColSizing), default="auto", help="""
-    Describes how the component should maintain its columns' widths.
-
-    .. note::
-        This is an experimental feature and may change in future. Use it at your
-        own discretion.
-
-    """)
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
 
     def _sphinx_height_hint(self) -> int|None:
         if any(x._sphinx_height_hint() is None for x in self.children):
             return None
         return max(x._sphinx_height_hint() for x in self.children)
 
-class Column(Box):
+class Column(FlexBox):
     ''' Lay out child components in a single vertical row.
 
     Children can be specified as positional arguments, as a single argument
     that is a sequence, or using the ``children`` keyword argument.
     '''
 
-    rows = Either(QuickTrackSizing, Dict(IntOrString, RowSizing), default="auto", help="""
-    Describes how the component should maintain its rows' heights.
-
-    .. note::
-        This is an experimental feature and may change in future. Use it at your
-        own discretion.
-
-    """)
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
 
     def _sphinx_height_hint(self) -> int|None:
         if any(x._sphinx_height_hint() is None for x in self.children):
             return None
         return sum(x._sphinx_height_hint() for x in self.children)
 
-class Panel(Model):
+class TabPanel(Model):
     ''' A single-widget container with title bar and controls.
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     title = String(default="", help="""
     The text title of the panel.
     """)
 
-    child = Instance(LayoutDOM, help="""
+    child = Instance(UIElement, help="""
     The child widget. If you need more children, use a layout widget, e.g. a ``Column``.
     """)
 
@@ -491,12 +573,16 @@ class Tabs(LayoutDOM):
 
     '''
 
-    __example__ = "sphinx/source/docs/user_guide/examples/interaction_tab_panes.py"
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
 
-    tabs = List(Instance(Panel), help="""
+    __example__ = "examples/interaction/widgets/tab_panes.py"
+
+    tabs = List(Instance(TabPanel), help="""
     The list of child panel widgets.
-    """).accepts(List(Tuple(String, Instance(LayoutDOM))),
-                 lambda items: [ Panel(title=title, child=child) for (title, child) in items ])
+    """).accepts(List(Tuple(String, Instance(UIElement))),
+                 lambda items: [ TabPanel(title=title, child=child) for (title, child) in items ])
 
     tabs_location = Enum(Location, default="above", help="""
     The location of the buttons that activate tabs.
@@ -506,6 +592,52 @@ class Tabs(LayoutDOM):
     The index of the active tab.
     """)
 
+class GroupBox(LayoutDOM):
+    ''' A panel that allows to group UI elements.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    title = Nullable(String, help="""
+    The title text of the group. If not provided, only the frame will be showed.
+    """)
+
+    child = Instance(UIElement, help="""
+    The child UI element. This can be a single UI control, widget, etc., or
+    a container layout like ``Column`` or ``Row``, or a combitation of layouts.
+    """)
+
+    checkable = Bool(False, help="""
+    Whether to allow disabling this group (all its children) via a checkbox
+    in the UI. This allows to broadcast ``disabled`` state across multiple
+    UI controls that support that state.
+    """)
+
+class ScrollBox(LayoutDOM):
+    ''' A panel that allows to scroll overflowing UI elements.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    child = Instance(UIElement, help="""
+    The child UI element. This can be a single UI control, widget, etc., or
+    a container layout like ``Column`` or ``Row``, or a combitation of layouts.
+    """)
+
+    horizontal_scrollbar = Enum(ScrollbarPolicy, default="auto", help="""
+    The visibility of the horizontal scrollbar.
+    """)
+
+    vertical_scrollbar = Enum(ScrollbarPolicy, default="auto", help="""
+    The visibility of the vertical scrollbar.
+    """)
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
@@ -517,15 +649,3 @@ class Tabs(LayoutDOM):
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
-
-# TODO (bev) deprecation: 3.0
-class WidgetBox(Column):
-    ''' Create a column of bokeh widgets with predefined styling.
-
-    WidgetBox is DEPRECATED and will beremoved in Bokeh 3.0, use 'Column' instead.
-
-    '''
-    def __init__(self, *args, **kw) -> None:
-        super().__init__(*args, **kw)
-        from ..util.deprecation import deprecated
-        deprecated("'WidgetBox' is deprecated and will be removed in Bokeh 3.0, use 'bokeh.models.Column' instead")
