@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -62,6 +62,8 @@ __all__ = (
     'LinearColorMapper',
     'LogColorMapper',
     'EqHistColorMapper',
+    'StackColorMapper',
+    'WeightedStackColorMapper',
 )
 
 #-----------------------------------------------------------------------------
@@ -73,7 +75,11 @@ class Mapper(Transform):
     ''' Base class for mappers.
 
     '''
-    pass
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 @abstract
 class ColorMapper(Mapper):
@@ -81,6 +87,11 @@ class ColorMapper(Mapper):
 
     '''
 
+    def __init__(self, *args, **kwargs) -> None:
+        if len(args) == 1:
+            kwargs['palette'] = args[0]
+        super().__init__(**kwargs)
+
     palette = Seq(Color, help="""
     A sequence of colors to use as the target palette for mapping.
 
@@ -92,10 +103,6 @@ class ColorMapper(Mapper):
     Color to be used if data is NaN or otherwise not mappable.
     """)
 
-    def __init__(self, palette=None, **kwargs) -> None:
-        if palette is not None:
-            kwargs['palette'] = palette
-        super().__init__(**kwargs)
 
 @abstract
 class CategoricalMapper(Mapper):
@@ -103,6 +110,10 @@ class CategoricalMapper(Mapper):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     factors = FactorSeq(help="""
     A sequence of factors / categories that map to the some target range. For
     example the following color mapper:
@@ -144,6 +155,10 @@ class CategoricalColorMapper(CategoricalMapper, ColorMapper):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     @warning(PALETTE_LENGTH_FACTORS_MISMATCH)
     def _check_palette_length(self):
         palette = self.palette
@@ -164,6 +179,10 @@ class CategoricalMarkerMapper(CategoricalMapper):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     markers = Seq(MarkerType, help="""
     A sequence of marker types to use as the target for mapping.
     """)
@@ -183,6 +202,10 @@ class CategoricalPatternMapper(CategoricalMapper):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     patterns = Seq(HatchPatternType, help="""
     A sequence of marker types to use as the target for mapping.
     """)
@@ -198,6 +221,10 @@ class ContinuousColorMapper(ColorMapper):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     domain = List(Tuple(Instance("bokeh.models.renderers.GlyphRenderer"), Either(String, List(String))), default=[], help="""
     A collection of glyph renderers to pool data from for establishing data metrics.
     If empty, mapped data will be used instead.
@@ -238,6 +265,10 @@ class LinearColorMapper(ContinuousColorMapper):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 class LogColorMapper(ContinuousColorMapper):
     ''' Map numbers in a range [*low*, *high*] into a sequence of colors
     (a palette) on a natural logarithm scale.
@@ -257,11 +288,27 @@ class LogColorMapper(ContinuousColorMapper):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 @abstract
 class ScanningColorMapper(ContinuousColorMapper):
-    pass
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
 
 class EqHistColorMapper(ScanningColorMapper):
+    '''
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     bins = Int(default=256*256, help="Number of histogram bins")
 
     rescale_discrete_levels = Bool(default=False, help="""
@@ -271,6 +318,52 @@ class EqHistColorMapper(ScanningColorMapper):
     palette.
     """)
 
+@abstract
+class StackColorMapper(ColorMapper):
+    ''' Abstract base class for color mappers that operate on ``ImageStack``
+    glyphs.
+
+    These map 3D data arrays of shape ``(ny, nx, nstack)`` to 2D RGBA images
+    of shape ``(ny, nx)``.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+class WeightedStackColorMapper(StackColorMapper):
+    ''' Maps 3D data arrays of shape ``(ny, nx, nstack)`` to 2D RGBA images
+    of shape ``(ny, nx)`` using a palette of length ``nstack``.
+
+    The mapping occurs in two stages. Firstly the RGB values are calculated
+    using a weighted sum of the palette colors in the ``nstack`` direction.
+    Then the alpha values are calculated using the ``alpha_mapper`` applied to
+    the sum of the array in the ``nstack`` direction.
+
+    The RGB values calculated by the ``alpha_mapper`` are ignored by the color
+    mapping but are used in any ``ColorBar`` that is displayed.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    alpha_mapper = Instance(ContinuousColorMapper, help="""
+    Color mapper used to calculate the alpha values of the mapped data.
+    """)
+
+    color_baseline = Nullable(Float, help="""
+    Baseline value used for the weights when calculating the weighted sum of
+    palette colors. If ``None`` then the minimum of the supplied data is used
+    meaning that values at this minimum have a weight of zero and do not
+    contribute to the weighted sum. As a special case, if all data for a
+    particular output pixel are at the color baseline then the color is an
+    evenly weighted average of the colors corresponding to all such values,
+    to avoid the color being undefined.
+    """)
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
