@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,10 +21,7 @@ log = logging.getLogger(__name__)
 from typing import (
     TYPE_CHECKING,
     Any as TAny,
-    Dict as TDict,
-    List as TList,
     Sequence,
-    Tuple,
     Union,
     overload,
 )
@@ -87,11 +84,11 @@ __all__ = (
 if TYPE_CHECKING:
     import numpy.typing as npt
 
-    DataDict: TypeAlias = TDict[str, Union[Sequence[TAny], npt.NDArray[TAny], pd.Series, pd.Index]]
+    DataDict: TypeAlias = dict[str, Union[Sequence[TAny], npt.NDArray[TAny], pd.Series, pd.Index]]
 
-    Index: TypeAlias = Union[int, slice, Tuple[Union[int, slice], ...]]
+    Index: TypeAlias = Union[int, slice, tuple[Union[int, slice], ...]]
 
-    Patches: TypeAlias = TDict[str, TList[Tuple[Index, Any]]]
+    Patches: TypeAlias = dict[str, list[tuple[Index, Any]]]
 
 @abstract
 class DataSource(Model):
@@ -203,9 +200,9 @@ class ColumnDataSource(ColumnarDataSource):
     objects. In these cases, the behaviour is identical to passing the objects
     to the ``ColumnDataSource`` initializer.
     """).accepts(
-        Object("pandas.DataFrame"), lambda x: ColumnDataSource._data_from_df(x)
+        Object("pandas.DataFrame"), lambda x: ColumnDataSource._data_from_df(x),
     ).accepts(
-        Object("pandas.core.groupby.GroupBy"), lambda x: ColumnDataSource._data_from_groupby(x)
+        Object("pandas.core.groupby.GroupBy"), lambda x: ColumnDataSource._data_from_groupby(x),
     ).asserts(lambda _, data: len({len(x) for x in data.values()}) <= 1,
                  lambda obj, name, data: warn(
                     "ColumnDataSource's columns must be of the same length. " +
@@ -529,16 +526,14 @@ class ColumnDataSource(ColumnarDataSource):
         oldkeys = set(self.data.keys())
 
         if newkeys != oldkeys:
-            missing = oldkeys - newkeys
-            extra = newkeys - oldkeys
+            missing = sorted(oldkeys - newkeys)
+            extra = sorted(newkeys - oldkeys)
             if missing and extra:
-                raise ValueError(
-                    "Must stream updates to all existing columns (missing: %s, extra: %s)" % (", ".join(sorted(missing)), ", ".join(sorted(extra)))
-                )
+                raise ValueError(f"Must stream updates to all existing columns (missing: {', '.join(missing)}, extra: {', '.join(extra)})")
             elif missing:
-                raise ValueError("Must stream updates to all existing columns (missing: %s)" % ", ".join(sorted(missing)))
+                raise ValueError(f"Must stream updates to all existing columns (missing: {', '.join(missing)})")
             else:
-                raise ValueError("Must stream updates to all existing columns (extra: %s)" % ", ".join(sorted(extra)))
+                raise ValueError(f"Must stream updates to all existing columns (extra: {', '.join(extra)})")
 
         if needs_length_check:
             lengths: set[int] = set()
@@ -546,7 +541,7 @@ class ColumnDataSource(ColumnarDataSource):
             for _, x in new_data.items():
                 if isinstance(x, arr_types):
                     if len(x.shape) != 1:
-                        raise ValueError("stream(...) only supports 1d sequences, got ndarray with size %r" % (x.shape,))
+                        raise ValueError(f"stream(...) only supports 1d sequences, got ndarray with size {x.shape!r}")
                     lengths.add(x.shape[0])
                 else:
                     lengths.add(len(x))
