@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -178,7 +178,14 @@ class CompositeTicker(ContinuousTicker):
 
     """)
 
-class SingleIntervalTicker(ContinuousTicker):
+class BaseSingleIntervalTicker(ContinuousTicker):
+    ''' Base class for single interval tickers. '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+class SingleIntervalTicker(BaseSingleIntervalTicker):
     ''' Generate evenly spaced ticks at a fixed interval regardless of
     scale.
 
@@ -192,7 +199,7 @@ class SingleIntervalTicker(ContinuousTicker):
     The interval between adjacent ticks.
     """)
 
-class DaysTicker(SingleIntervalTicker):
+class DaysTicker(BaseSingleIntervalTicker):
     ''' Generate ticks spaced apart by specific, even multiples of days.
 
     '''
@@ -207,7 +214,7 @@ class DaysTicker(SingleIntervalTicker):
 
     num_minor_ticks = Override(default=0)
 
-class MonthsTicker(SingleIntervalTicker):
+class MonthsTicker(BaseSingleIntervalTicker):
     ''' Generate ticks spaced apart by specific, even multiples of months.
 
     '''
@@ -220,7 +227,7 @@ class MonthsTicker(SingleIntervalTicker):
     The intervals of months to use.
     """)
 
-class YearsTicker(SingleIntervalTicker):
+class YearsTicker(BaseSingleIntervalTicker):
     ''' Generate ticks spaced apart even numbers of years.
 
     '''
@@ -319,21 +326,21 @@ class DatetimeTicker(CompositeTicker):
             base=10,
             min_interval=0,
             max_interval=500*ONE_MILLI,
-            num_minor_ticks=0
+            num_minor_ticks=0,
         ),
         AdaptiveTicker(
             mantissas=[1, 2, 5, 10, 15, 20, 30],
             base=60,
             min_interval=ONE_SECOND,
             max_interval=30*ONE_MINUTE,
-            num_minor_ticks=0
+            num_minor_ticks=0,
         ),
         AdaptiveTicker(
             mantissas=[1, 2, 4, 6, 8, 12],
             base=24,
             min_interval=ONE_HOUR,
             max_interval=12*ONE_HOUR,
-            num_minor_ticks=0
+            num_minor_ticks=0,
         ),
         DaysTicker(days=list(range(1, 32))),
         DaysTicker(days=list(range(1, 31, 3))),
