@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -49,6 +49,7 @@ from ..core.enums import (
     Anchor,
     Dimension,
     Dimensions,
+    KeyModifier,
     SelectionMode,
     ToolIcon,
     TooltipAttachment,
@@ -63,6 +64,7 @@ from ..core.properties import (
     Color,
     Date,
     Datetime,
+    DeprecatedAlias,
     Dict,
     Either,
     Enum,
@@ -77,11 +79,12 @@ from ..core.properties import (
     Override,
     Percent,
     Regex,
-    Required,
     Seq,
     String,
+    Struct,
     Tuple,
 )
+from ..core.property.struct import Optional
 from ..core.validation import error
 from ..core.validation.errors import (
     INCOMPATIBLE_BOX_EDIT_RENDERER,
@@ -169,8 +172,8 @@ class Tool(Model):
     # explicit __init__ to support Init signatures
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
-
-    icon = Nullable(Either(Enum(ToolIcon), Regex(r"^\."), Image), help="""
+    #Image has to be first! see #12775, temporary fix
+    icon = Nullable(Either(Image, Enum(ToolIcon), Regex(r"^\.")), help="""
     An icon to display in the toolbar.
 
     The icon can provided as well known tool icon name, a CSS class selector,
@@ -295,6 +298,29 @@ class SelectTool(GestureTool):
     the selection, intersect with it or subtract from it.
     """)
 
+@abstract
+class RegionSelectTool(SelectTool):
+    ''' Base class for region selection tools (e.g. box, polygon, lasso).
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    continuous = Bool(False, help="""
+    Whether a selection computation should happen continuously during selection
+    gestures, or only once when the selection region is completed.
+    """)
+
+    select_every_mousemove = DeprecatedAlias("continuous", since=(3, 1, 0))
+
+    persistent = Bool(default=False, help="""
+    Whether the selection overlay should persist after selection gesture
+    is completed. This can be paired with setting ``editable = True`` on
+    the annotation, to allow to modify the selection.
+    """)
+
 @abstract
 class InspectTool(GestureTool):
     ''' A base class for tools that perform "inspections", e.g. ``HoverTool``.
@@ -392,15 +418,18 @@ class PanTool(Drag):
 DEFAULT_RANGE_OVERLAY = InstanceDefault(BoxAnnotation,
     syncable=False,
     level="overlay",
+    visible=True,
+    editable=True,
+    propagate_hover=True,
     fill_color="lightgrey",
     fill_alpha=0.5,
     line_color="black",
     line_alpha=1.0,
     line_width=0.5,
-    line_dash=[2,2],
+    line_dash=[2, 2],
 )
 
-class RangeTool(Drag):
+class RangeTool(Tool):
     ''' *toolbar icon*: |range_icon|
 
     The range tool allows the user to update range objects for either or both
@@ -427,6 +456,11 @@ class RangeTool(Drag):
     will span the entire x-dimension.
     """)
 
+    y_range = Nullable(Instance(Range1d), help="""
+    A range synchronized to the y-dimension of the overlay. If None, the overlay
+    will span the entire y-dimension.
+    """)
+
     x_interaction = Bool(default=True, help="""
     Whether to respond to horizontal pan motions when an ``x_range`` is present.
 
@@ -437,11 +471,6 @@ class RangeTool(Drag):
     update if the ``x_range`` is updated programmatically.)
     """)
 
-    y_range = Nullable(Instance(Range1d), help="""
-    A range synchronized to the y-dimension of the overlay. If None, the overlay
-    will span the entire y-dimension.
-    """)
-
     y_interaction = Bool(default=True, help="""
     Whether to respond to vertical pan motions when a ``y_range`` is present.
 
@@ -519,7 +548,23 @@ class WheelZoomTool(Scroll):
 
     zoom_on_axis = Bool(default=True, help="""
     Whether scrolling on an axis (outside the central plot area) should zoom
-    that dimension.
+    that dimension. If enabled, the behavior of this feature can be configured
+    with ``zoom_together`` property.
+    """)
+
+    zoom_together = Enum("none", "cross", "all", default="all", help="""
+    Defines the behavior of the tool when zooming on an axis:
+
+    - ``"none"``
+        zoom only the axis that's being interacted with. Any cross
+        axes nor any other axes in the dimension of this axis will be affected.
+    - ``"cross"``
+        zoom the axis that's being interacted with and its cross
+        axis, if configured. No other axes in this or cross dimension will be
+        affected.
+    - ``"all"``
+        zoom all axes in the dimension of the axis that's being
+        interacted with. All cross axes will be unaffected.
     """)
 
     speed = Float(default=1/600, help="""
@@ -627,7 +672,7 @@ class TapTool(Tap, SelectTool):
 
     .. note::
         Selections can be comprised of multiple regions, even those
-        made by different selection tools. Hold down the <<shift>> key
+        made by different selection tools. Hold down the SHIFT key
         while making a selection to append the new selection to any
         previous selection that might exist.
 
@@ -650,6 +695,16 @@ class TapTool(Tap, SelectTool):
     either a single or double tap.
     """)
 
+    modifiers = Struct(shift=Optional(Bool), ctrl=Optional(Bool), alt=Optional(Bool), default={}, help="""
+    Allows to configure a combination of modifier keys, which need to
+    be pressed during the selected gesture for this tool to trigger.
+
+    .. warning::
+        Configuring modifiers is a platform dependent feature and
+        can make this tool unsable for example on mobile devices.
+
+    """).accepts(Enum(KeyModifier), lambda key_mod: {key_mod: True})
+
     callback = Nullable(Instance(Callback), help="""
     A callback to execute *whenever a glyph is "hit"* by a mouse click
     or tap.
@@ -742,10 +797,11 @@ class CrosshairTool(InspectTool):
     Stroke width in units of pixels.
     """)
 
-DEFAULT_BOX_OVERLAY = InstanceDefault(BoxAnnotation,
+DEFAULT_BOX_ZOOM_OVERLAY = InstanceDefault(BoxAnnotation,
     syncable=False,
     level="overlay",
     visible=False,
+    editable=False,
     top_units="canvas",
     left_units="canvas",
     bottom_units="canvas",
@@ -758,6 +814,23 @@ DEFAULT_BOX_OVERLAY = InstanceDefault(BoxAnnotation,
     line_dash=[4, 4],
 )
 
+DEFAULT_BOX_SELECT_OVERLAY = InstanceDefault(BoxAnnotation,
+    syncable=False,
+    level="overlay",
+    visible=False,
+    editable=True,
+    top_units="data",
+    left_units="data",
+    bottom_units="data",
+    right_units="data",
+    fill_color="lightgrey",
+    fill_alpha=0.5,
+    line_color="black",
+    line_alpha=1.0,
+    line_width=2,
+    line_dash=[4, 4],
+)
+
 class BoxZoomTool(Drag):
     ''' *toolbar icon*: |box_zoom_icon|
 
@@ -789,7 +862,7 @@ class BoxZoomTool(Drag):
     of the plot, and the vertical dimension can be controlled.
     """)
 
-    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_OVERLAY, help="""
+    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_ZOOM_OVERLAY, help="""
     A shaded annotation drawn to indicate the selection region.
     """)
 
@@ -808,7 +881,20 @@ class BoxZoomTool(Drag):
     (top-left or bottom-right depending on direction) or the center of the box.
     """)
 
-class ZoomInTool(PlotActionTool):
+@abstract
+class ZoomBaseTool(PlotActionTool):
+    """ Abstract base class for zoom action tools. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    renderers = Either(Auto, List(Instance(DataRenderer)), default="auto", help="""
+    Restrict zoom to ranges used by the provided data renderers. If ``"auto"``
+    then all ranges provided by the cartesian frame will be used.
+    """)
+
+class ZoomInTool(ZoomBaseTool):
     ''' *toolbar icon*: |zoom_in_icon|
 
     The zoom-in tool allows users to click a button to zoom in
@@ -836,7 +922,7 @@ class ZoomInTool(PlotActionTool):
     Percentage to zoom for each click of the zoom-in tool.
     """)
 
-class ZoomOutTool(PlotActionTool):
+class ZoomOutTool(ZoomBaseTool):
     ''' *toolbar icon*: |zoom_out_icon|
 
     The zoom-out tool allows users to click a button to zoom out
@@ -870,7 +956,7 @@ class ZoomOutTool(PlotActionTool):
     that causes overall focus or aspect ratio to change.
     """)
 
-class BoxSelectTool(Drag, SelectTool):
+class BoxSelectTool(Drag, RegionSelectTool):
     ''' *toolbar icon*: |box_select_icon|
 
     The box selection tool allows users to make selections on a Plot by showing
@@ -891,11 +977,6 @@ class BoxSelectTool(Drag, SelectTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    select_every_mousemove = Bool(False, help="""
-    Whether a selection computation should happen on every mouse event, or only
-    once, when the selection region is completed. Default: False
-    """)
-
     dimensions = Enum(Dimensions, default="both", help="""
     Which dimensions the box selection is to be free in. By default, users may
     freely draw selections boxes with any dimensions. If only "width" is set,
@@ -905,7 +986,7 @@ class BoxSelectTool(Drag, SelectTool):
     plot, and the vertical dimension can be controlled.
     """)
 
-    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_OVERLAY, help="""
+    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_SELECT_OVERLAY, help="""
     A shaded annotation drawn to indicate the selection region.
     """)
 
@@ -918,17 +999,18 @@ DEFAULT_POLY_OVERLAY = InstanceDefault(PolyAnnotation,
     syncable=False,
     level="overlay",
     visible=False,
-    xs_units="canvas",
-    ys_units="canvas",
+    editable=True,
+    xs_units="data",
+    ys_units="data",
     fill_color="lightgrey",
     fill_alpha=0.5,
     line_color="black",
     line_alpha=1.0,
     line_width=2,
-    line_dash=[4, 4]
+    line_dash=[4, 4],
 )
 
-class LassoSelectTool(Drag, SelectTool):
+class LassoSelectTool(Drag, RegionSelectTool):
     ''' *toolbar icon*: |lasso_select_icon|
 
     The lasso selection tool allows users to make selections on a Plot by
@@ -941,7 +1023,7 @@ class LassoSelectTool(Drag, SelectTool):
 
     .. note::
         Selections can be comprised of multiple regions, even those made by
-        different selection tools. Hold down the <<shift>> key while making a
+        different selection tools. Hold down the SHIFT key while making a
         selection to append the new selection to any previous selection that
         might exist.
 
@@ -955,16 +1037,13 @@ class LassoSelectTool(Drag, SelectTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    select_every_mousemove = Bool(True, help="""
-    Whether a selection computation should happen on every mouse event, or only
-    once, when the selection region is completed.
-    """)
-
     overlay = Instance(PolyAnnotation, default=DEFAULT_POLY_OVERLAY, help="""
     A shaded annotation drawn to indicate the selection region.
     """)
 
-class PolySelectTool(Tap, SelectTool):
+    continuous = Override(default=True)
+
+class PolySelectTool(Tap, RegionSelectTool):
     ''' *toolbar icon*: |poly_select_icon|
 
     The polygon selection tool allows users to make selections on a
@@ -978,7 +1057,7 @@ class PolySelectTool(Tap, SelectTool):
 
     .. note::
         Selections can be comprised of multiple regions, even those
-        made by different selection tools. Hold down the <<shift>> key
+        made by different selection tools. Hold down the SHIFT key
         while making a selection to append the new selection to any
         previous selection that might exist.
 
@@ -1119,7 +1198,7 @@ class HoverTool(InspectTool):
             ("foo", "@foo"),
             ("bar", "@bar"),
             ("baz", "@baz{safe}"),
-            ("total", "@total{$0,0.00}"
+            ("total", "@total{$0,0.00}"),
         ]
 
     You can also supply a ``Callback`` to the ``HoverTool``, to build custom
@@ -1327,7 +1406,7 @@ class HoverTool(InspectTool):
     """)
 
 DEFAULT_HELP_TIP = "Click the question mark to learn more about Bokeh plot tools."
-DEFAULT_HELP_URL = "https://docs.bokeh.org/en/latest/docs/user_guide/tools.html"
+DEFAULT_HELP_URL = "https://docs.bokeh.org/en/latest/docs/user_guide/interaction/tools.html"
 
 class HelpTool(ActionTool):
     ''' A button tool to provide a "help" link to users.
@@ -1401,7 +1480,7 @@ class EditTool(GestureTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    empty_value = Required(Either(Bool, Int, Float, Date, Datetime, Color, String), help="""
+    empty_value = Either(Bool, Int, Float, Date, Datetime, Color, String, default=0, help="""
     Defines the value to insert on non-coordinate columns when a new
     glyph is inserted into the ``ColumnDataSource`` columns, e.g. when a
     circle glyph defines 'x', 'y' and 'color' columns, adding a new
@@ -1462,17 +1541,17 @@ class BoxEditTool(EditTool, Drag, Tap):
     * Move box: Click and drag an existing box, the box will be dropped once
       you let go of the mouse button.
 
-    * Delete box: Tap a box to select it then press <<backspace>> key while the
+    * Delete box: Tap a box to select it then press BACKSPACE key while the
       mouse is within the plot area.
 
     To **Move** or **Delete** multiple boxes at once:
 
-    * Move selection: Select box(es) with <<shift>>+tap (or another selection
+    * Move selection: Select box(es) with SHIFT+tap (or another selection
       tool) then drag anywhere on the plot. Selecting and then dragging on a
       specific box will move both.
 
-    * Delete selection: Select box(es) with <<shift>>+tap (or another selection
-      tool) then press <<backspace>> while the mouse is within the plot area.
+    * Delete selection: Select box(es) with SHIFT+tap (or another selection
+      tool) then press BACKSPACE while the mouse is within the plot area.
 
     .. |box_edit_icon| image:: /_images/icons/BoxEdit.png
         :height: 24px
@@ -1512,7 +1591,7 @@ class PointDrawTool(EditTool, Drag, Tap):
     ''' *toolbar icon*: |point_draw_icon|
 
     The PointDrawTool allows adding, dragging and deleting point-like glyphs
-    (i.e subclasses of``XYGlyph``) on one or more renderers by editing the
+    (i.e subclasses of ``XYGlyph``) on one or more renderers by editing the
     underlying ``ColumnDataSource`` data. Like other drawing tools, the
     renderers that are to be edited must be supplied explicitly as a list. Any
     newly added points will be inserted on the ``ColumnDataSource`` of the
@@ -1536,7 +1615,7 @@ class PointDrawTool(EditTool, Drag, Tap):
     * Move point: Tap and drag an existing point, the point will be
       dropped once you let go of the mouse button.
 
-    * Delete point: Tap a point to select it then press <<backspace>>
+    * Delete point: Tap a point to select it then press BACKSPACE
       key while the mouse is within the plot area.
 
     .. |point_draw_icon| image:: /_images/icons/PointDraw.png
@@ -1595,13 +1674,13 @@ class PolyDrawTool(PolyTool, Drag, Tap):
 
     * Add patch or multi-line: Double tap to add the first vertex, then use tap
       to add each subsequent vertex, to finalize the draw action double tap to
-      insert the final vertex or press the <<esc> key.
+      insert the final vertex or press the ESC key.
 
-    * Move patch or ulti-line: Tap and drag an existing patch/multi-line, the
+    * Move patch or multi-line: Tap and drag an existing patch/multi-line, the
       point will be dropped once you let go of the mouse button.
 
     * Delete patch or multi-line: Tap a patch/multi-line to select it then
-      press <<backspace>> key while the mouse is within the plot area.
+      press BACKSPACE key while the mouse is within the plot area.
 
     .. |poly_draw_icon| image:: /_images/icons/PolyDraw.png
         :height: 24px
@@ -1650,7 +1729,7 @@ class FreehandDrawTool(EditTool, Drag, Tap):
     * Draw vertices: Click and drag to draw a line
 
     * Delete patch/multi-line: Tap a patch/multi-line to select it then press
-      <<backspace>> key while the mouse is within the plot area.
+      BACKSPACE key while the mouse is within the plot area.
 
     .. |freehand_draw_icon| image:: /_images/icons/FreehandDraw.png
         :height: 24px
@@ -1689,7 +1768,7 @@ class PolyEditTool(PolyTool, Drag, Tap):
 
     The tool will modify the columns on the data source corresponding to the
     ``xs`` and ``ys`` values of the glyph. Any additional columns in the data
-    source will be padded with the declared``empty_value``, when adding a new
+    source will be padded with the declared ``empty_value``, when adding a new
     point.
 
     The supported actions include:
@@ -1698,12 +1777,12 @@ class PolyEditTool(PolyTool, Drag, Tap):
 
     * Add vertex: Double tap an existing vertex to select it, the tool will
       draw the next point, to add it tap in a new location. To finish editing
-      and add a point double tap otherwise press the <<esc> key to cancel.
+      and add a point double tap otherwise press the ESC key to cancel.
 
     * Move vertex: Drag an existing vertex and let go of the mouse button to
       release it.
 
-    * Delete vertex: After selecting one or more vertices press <<backspace>>
+    * Delete vertex: After selecting one or more vertices press BACKSPACE
       while the mouse cursor is within the plot area.
 
     .. |poly_edit_icon| image:: /_images/icons/PolyEdit.png
@@ -1738,7 +1817,7 @@ class LineEditTool(EditTool, Drag, Tap):
 
     The tool will modify the columns on the data source corresponding to the
     ``x`` and ``y`` values of the glyph. Any additional columns in the data
-    source will be padded with the declared``empty_value``, when adding a new
+    source will be padded with the declared ``empty_value``, when adding a new
     point.
 
     The supported actions include:
