@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -39,6 +39,7 @@ from itertools import permutations
 from typing import TYPE_CHECKING
 
 # Bokeh imports
+from bokeh.core.properties import UnsetValueError
 from bokeh.layouts import column
 from bokeh.models import (
     BoxZoomTool,
@@ -169,15 +170,15 @@ class _BokehStructureGraph:
             answer3: bool = False
             try:
                 answer1 = s in getattr(H, y)
-            except TypeError:
+            except (TypeError, UnsetValueError):
                 pass
             try:
                 answer2 = s == getattr(H, y)
-            except TypeError:
+            except (TypeError, UnsetValueError):
                 pass
             try:
                 answer3 = s in getattr(H, y).values()
-            except (AttributeError, ValueError):
+            except (AttributeError, ValueError, UnsetValueError):
                 pass
             return answer1 | answer2 | answer3
 
@@ -187,7 +188,7 @@ class _BokehStructureGraph:
             T[m.id] = {y.id for y in m.references()}
 
         K.add_nodes_from(
-            [(x, {"model": M.select_one({"id": x}).__class__.__name__}) for x in T]
+            [(x, {"model": M.select_one({"id": x}).__class__.__name__}) for x in T],
         )
         E = [(y, x) for x, y in permutations(T, 2) if T[x] <= T[y]]
         K.add_edges_from(E)
@@ -233,7 +234,7 @@ class _BokehStructureGraph:
         models = [self._graph.nodes[x]["model"] for x in nodes]
         node_id = list(nodes.keys())
         node_source = ColumnDataSource(
-            {"x": node_x, "y": node_y, "index": node_id, "model": models}
+            {"x": node_x, "y": node_y, "index": node_id, "model": models},
         )
         edge_x_coords = []
         edge_y_coords = []
@@ -246,10 +247,10 @@ class _BokehStructureGraph:
         xinterval = max(max(node_x) - min(node_x), 200)
         yinterval = max(max(node_y) - min(node_y), 200)
         p2.x_range = Range1d(
-            start=min(node_x) - 0.15 * xinterval, end=max(node_x) + 0.15 * xinterval
+            start=min(node_x) - 0.15 * xinterval, end=max(node_x) + 0.15 * xinterval,
         )
         p2.y_range = Range1d(
-            start=min(node_y) - 0.15 * yinterval, end=max(node_y) + 0.15 * yinterval
+            start=min(node_y) - 0.15 * yinterval, end=max(node_y) + 0.15 * yinterval,
         )
 
         node_renderer = GlyphRenderer(
@@ -260,7 +261,7 @@ class _BokehStructureGraph:
         )
 
         edge_renderer = GlyphRenderer(
-            data_source=edge_source, glyph=MultiLine(xs="xs", ys="ys")
+            data_source=edge_source, glyph=MultiLine(xs="xs", ys="ys"),
         )
 
         node_hover_tool = HoverTool(tooltips=[("id", "@index"), ("model", "@model")])
@@ -292,7 +293,7 @@ class _BokehStructureGraph:
         p2.add_layout(edge_renderer)
         p2.add_layout(node_renderer)
         p2.tools.extend(
-            [node_hover_tool, tap_tool, BoxZoomTool(), ResetTool(), PanTool()]
+            [node_hover_tool, tap_tool, BoxZoomTool(), ResetTool(), PanTool()],
         )
         p2.renderers.append(labels)
         self._node_source = node_source
