@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,12 +21,10 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Bokeh imports
-from ...core.enums import CalendarPosition
 from ...core.has_props import abstract
 from ...core.properties import (
     Bool,
     ColorHex,
-    Date,
     Dict,
     Either,
     Enum,
@@ -56,7 +54,6 @@ __all__ = (
     'AutocompleteInput',
     'Checkbox',
     'ColorPicker',
-    'DatePicker',
     'FileInput',
     'InputWidget',
     'MultiChoice',
@@ -66,8 +63,8 @@ __all__ = (
     'Select',
     'Spinner',
     'Switch',
+    'TextAreaInput',
     'TextInput',
-    'TextAreaInput'
 )
 
 #-----------------------------------------------------------------------------
@@ -118,10 +115,10 @@ class FileInput(InputWidget):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    value = Readonly(Either(String, List(String)), default="", help='''
+    value = Readonly(Either(String, List(String)), help='''
     The base64-enconded contents of the file or files that were loaded.
 
-    If `mulitiple` is set to False (default), this value is a single string with the contents
+    If `multiple` is set to False (default), this value is a single string with the contents
     of the single file that was chosen.
 
     If `multiple` is True, this value is a list of strings, each containing the contents of
@@ -130,10 +127,10 @@ class FileInput(InputWidget):
     The sequence of files is given by the list of filenames (see below)
     ''')
 
-    mime_type = Readonly(Either(String, List(String)), default="", help='''
+    mime_type = Readonly(Either(String, List(String)), help='''
     The mime-type of the file or files that were loaded.
 
-    If `mulitiple` is set to False (default), this value is a single string with the
+    If `multiple` is set to False (default), this value is a single string with the
     mime-type of the single file that was chosen.
 
     If `multiple` is True, this value is a list of strings, each containing the
@@ -142,10 +139,10 @@ class FileInput(InputWidget):
     The sequence of files is given by the list of filename (see below)
     ''')
 
-    filename = Readonly(Either(String, List(String)), default="", help='''
+    filename = Readonly(Either(String, List(String)), help='''
     The name(s) of the file or files that were loaded.
 
-    If `mulitiple` is set to False (default), this value is a single string with the
+    If `multiple` is set to False (default), this value is a single string with the
     name of the single file that was chosen.
 
     If `multiple` is True, this value is a list of strings, each containing the
@@ -238,30 +235,28 @@ class Spinner(NumericInput):
 
     '''
 
+    # explicit __init__ to support Init signatures
     def __init__(self, *args, **kwargs) -> None:
-        if "value" in kwargs and "value_throttled" not in kwargs:
-            kwargs["value_throttled"] = kwargs["value"]
-
         super().__init__(*args, **kwargs)
 
     value_throttled = Readonly(Either(Null, Float, Int), help="""
-    value reported at the end of interactions
+    Value reported at the end of interactions.
     """)
 
     mode = Override(default="float")
 
     step = Interval(Float, start=1e-16, end=float('inf'), default=1, help="""
-    The step added or subtracted to the current value
+    The step added or subtracted to the current value.
     """)
 
     page_step_multiplier = Interval(Float, start=0, end=float('inf'), default=10, help="""
     Defines the multiplication factor applied to step when the page up and page
-    down keys are pressed
+    down keys are pressed.
     """)
 
     wheel_wait = Either(Int, Float, default=100, help="""
     Defines the debounce time in ms before updating `value_throttled` when the
-    mouse wheel is used to change the input
+    mouse wheel is used to change the input.
     """)
 
 @abstract
@@ -411,6 +406,13 @@ class AutocompleteInput(TextInput):
     Set to False in order to allow users to enter text that is not present in the list of completion strings.
     """)
 
+    search_strategy = Enum("starts_with", "includes", help="""
+    Define how to search the list of completion strings. The default option
+    ``"starts_with"`` means that the user's text must match the start of a
+    completion string. Using ``"includes"`` means that the user's text can
+    match any substring of a completion string.
+    """)
+
 
 class Select(InputWidget):
     ''' Single-select widget.
@@ -506,58 +508,8 @@ class MultiChoice(InputWidget):
     solid = Bool(default=True, help="""
     Specify whether the choices should be solidly filled.""")
 
-
-class DatePicker(InputWidget):
-    ''' Calendar-based date picker widget.
-
-    '''
-
-    # explicit __init__ to support Init signatures
-    def __init__(self, *args, **kwargs) -> None:
-        super().__init__(*args, **kwargs)
-
-    value = Date(help="""
-    The initial or picked date.
-    """)
-
-    min_date = Nullable(Date, help="""
-    Optional earliest allowable date.
-    """)
-
-    max_date = Nullable(Date, help="""
-    Optional latest allowable date.
-    """)
-
-    disabled_dates = Nullable(List(Either(Date, Tuple(Date, Date))), default=None, help="""
-    A list of dates of ``(start, end)`` date ranges to make unavailable for
-    selection. All other dates will be avalable.
-
-    .. note::
-        Only one of ``disabled_dates`` and ``enabled_dates`` should be specified.
-    """)
-
-    enabled_dates = Nullable(List(Either(Date, Tuple(Date, Date))), default=None, help="""
-    A list of dates of ``(start, end)`` date ranges to make available for
-    selection. All other dates will be unavailable.
-
-    .. note::
-        Only one of ``disabled_dates`` and ``enabled_dates`` should be specified.
-    """)
-
-    position = Enum(CalendarPosition, default="auto", help="""
-    Where the calendar is rendered relative to the input when ``inline`` is False.
-    """)
-
-    inline = Bool(default=False, help="""
-    Whether the calendar sholud be displayed inline.
-    """)
-
 class ColorPicker(InputWidget):
-    ''' Color picker widget
-
-    .. warning::
-        This widget as a limited support on *Internet Explorer* (it will be displayed
-        as a simple text input).
+    ''' Color picker widget.
 
     '''
 
