@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -505,7 +505,7 @@ class HTMLTemplateFormatter(CellFormatter):
 
         <a href="<%= url %>"><%= value %></a>
 
-    To use a different set of template delimiters, pass the appropriate values for `evaluate`, `interpolate',
+    To use a different set of template delimiters, pass the appropriate values for `evaluate`, `interpolate`,
     or `escape`.  See the Underscore `template` documentation for more information.  http://underscorejs.org/#template
 
     Example: Simple HTML template to format the column value as code.
