@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -27,6 +27,7 @@ log = logging.getLogger(__name__)
 
 # Bokeh imports
 from ...core.has_props import abstract
+from ...core.properties import Override
 from ..layouts import LayoutDOM
 
 #-----------------------------------------------------------------------------
@@ -55,6 +56,8 @@ class Widget(LayoutDOM):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    margin = Override(default=5)
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
