@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -120,6 +120,7 @@ class figure(Plot, GlyphAPI):
         * :func:`~bokeh.plotting.figure.dot`
         * :func:`~bokeh.plotting.figure.ellipse`
         * :func:`~bokeh.plotting.figure.harea`
+        * :func:`~bokeh.plotting.figure.harea_step`
         * :func:`~bokeh.plotting.figure.hbar`
         * :func:`~bokeh.plotting.figure.hex`
         * :func:`~bokeh.plotting.figure.hex_tile`
@@ -152,6 +153,7 @@ class figure(Plot, GlyphAPI):
         * :func:`~bokeh.plotting.figure.triangle_dot`
         * :func:`~bokeh.plotting.figure.triangle_pin`
         * :func:`~bokeh.plotting.figure.varea`
+        * :func:`~bokeh.plotting.figure.varea_step`
         * :func:`~bokeh.plotting.figure.vbar`
         * :func:`~bokeh.plotting.figure.wedge`
         * :func:`~bokeh.plotting.figure.x`
@@ -733,7 +735,7 @@ def markers():
     '''
     print("Available markers: \n\n - " + "\n - ".join(list(MarkerType)))
     print()
-    print("Shortcuts: \n\n" + "\n".join(" %r: %s" % item for item in _MARKER_SHORTCUTS.items()))
+    print("Shortcuts: \n\n" + "\n".join(f" {short!r}: {name}" for (short, name) in _MARKER_SHORTCUTS.items()))
 
 #-----------------------------------------------------------------------------
 # Dev API
