@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -61,11 +61,11 @@ class GlyphAPI:
         self._coordinates = coordinates
 
     @glyph_method(glyphs.AnnularWedge)
-    def annular_wedge(self, **kwargs):
+    def annular_wedge(self, **kwargs: Any) -> GlyphRenderer:
         pass
 
     @glyph_method(glyphs.Annulus)
-    def annulus(self, **kwargs):
+    def annulus(self, **kwargs: Any) -> GlyphRenderer:
         """
 Examples:
 
@@ -325,6 +325,23 @@ Examples:
 
         show(plot)
 
+"""
+
+    @glyph_method(glyphs.HAreaStep)
+    def harea_step(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(width=300, height=300)
+        plot.harea_step(x1=[1, 2, 3], x2=[0, 0, 0], y=[1, 4, 2],
+                        step_mode="after", fill_color="#99D594")
+
+        show(plot)
+
 """
 
     @glyph_method(glyphs.HBar)
@@ -341,6 +358,38 @@ Examples:
 
         show(plot)
 
+"""
+
+    @glyph_method(glyphs.HSpan)
+    def hspan(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(width=300, height=300, x_range=(0, 1))
+        plot.hspan(y=[1, 2, 3], color="#CAB2D6")
+
+        show(plot)
+
+"""
+
+    @glyph_method(glyphs.HStrip)
+    def hstrip(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(width=300, height=300, x_range=(0, 1))
+        plot.hstrip(y0=[1, 2, 5], y1=[3, 4, 8], color="#CAB2D6")
+
+        show(plot)
+
 """
 
     @glyph_method(glyphs.Ellipse)
@@ -428,6 +477,10 @@ Examples:
 
 """
 
+    @glyph_method(glyphs.ImageStack)
+    def image_stack(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        pass
+
     @glyph_method(glyphs.ImageURL)
     def image_url(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
         pass
@@ -612,6 +665,11 @@ Examples:
 
         show(plot)
 
+    .. warning::
+        ``Rect`` glyphs are not well defined on logarithmic scales. Use
+        :class:`~bokeh.models.Block` or :class:`~bokeh.models.Quad` glyphs
+        instead.
+
 """
 
     @glyph_method(glyphs.Step)
@@ -841,6 +899,23 @@ Examples:
 
         show(plot)
 
+"""
+
+    @glyph_method(glyphs.VAreaStep)
+    def varea_step(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(width=300, height=300)
+        plot.varea_step(x=[1, 2, 3], y1=[0, 0, 0], y2=[1, 4, 2],
+                        step_mode="after", fill_color="#99D594")
+
+        show(plot)
+
 """
 
     @glyph_method(glyphs.VBar)
@@ -857,6 +932,38 @@ Examples:
 
         show(plot)
 
+"""
+
+    @glyph_method(glyphs.VSpan)
+    def vspan(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(width=300, height=300, y_range=(0, 1))
+        plot.vspan(x=[1, 2, 3], color="#CAB2D6")
+
+        show(plot)
+
+"""
+
+    @glyph_method(glyphs.VStrip)
+    def vstrip(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(width=300, height=300, y_range=(0, 1))
+        plot.vstrip(x0=[1, 2, 5], x1=[3, 4, 8], color="#CAB2D6")
+
+        show(plot)
+
 """
 
     @glyph_method(glyphs.Wedge)
