@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -151,7 +151,7 @@ class Receiver:
         content = self._assume_text(fragment)
         self._fragments.append(content)
 
-        header_json, metadata_json, content_json = [self._assume_text(x) for x in self._fragments[:3]]
+        header_json, metadata_json, content_json = (self._assume_text(x) for x in self._fragments[:3])
 
         self._partial = self._protocol.assemble(header_json, metadata_json, content_json)
 
