@@ -1,12 +1,14 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 ''' Provide JSON data for co-occurrence of characters in Les Miserables.
 
-Derived from http://ftp.cs.stanford.edu/pub/sgb/jean.dat
+License: `CC BY-ND 4.0`_
+
+Source from http://ftp.cs.stanford.edu/pub/sgb/jean.dat
 
 This module contains one dictionary: ``data``.
 
@@ -27,6 +29,7 @@ This module contains one dictionary: ``data``.
         ]
     }
 
+.. bokeh-sampledata-xref:: les_mis
 '''
 
 #-----------------------------------------------------------------------------
@@ -41,11 +44,8 @@ log = logging.getLogger(__name__)
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-import json
-
 # Bokeh imports
-from ..util.sampledata import package_path
+from ..util.sampledata import load_json, package_path
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -71,4 +71,4 @@ __all__ = (
 # Code
 #-----------------------------------------------------------------------------
 
-data = json.load(open(package_path('les_mis.json')))
+data = load_json(package_path('les_mis.json'))
