@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -111,7 +111,7 @@ def _read_data() -> dict[tuple[State, County], CountyData]:
                 detailed_name = det_name,
                 state = state,
                 lats = lats,
-                lons = lons
+                lons = lons,
             )
 
     return data
