@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -91,7 +91,7 @@ class ProtocolHandler:
             handler = self._handlers.get(message.msgtype)
 
         if handler is None:
-            raise ProtocolError("%s not expected on server" % message)
+            raise ProtocolError(f"{message} not expected on server")
 
         try:
             work = await handler(message, connection)
