@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -18,6 +18,8 @@ There are two public classes in this module:
     :class:`~bokeh.application.application.Application` instances, and will
     automatically create and coordinate the lower level Tornado components.
 
+See :ref:`ug_server_introduction` for general information on the Bokeh server.
+
 '''
 
 #-----------------------------------------------------------------------------
@@ -54,7 +56,7 @@ from ..core.properties import (
     Nullable,
     String,
 )
-from ..resources import DEFAULT_SERVER_PORT
+from ..resources import DEFAULT_SERVER_PORT, server_url
 from ..util.options import Options
 from .tornado import DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES, BokehTornado
 from .util import bind_sockets, create_hosts_allowlist
@@ -95,8 +97,6 @@ class BaseServer:
     ``http_server`` must have been previously created and initialized with the
     ``BokehTornado`` instance.
 
-    .. autoclasstoc::
-
     '''
 
     def __init__(self, io_loop: IOLoop, tornado_app: BokehTornado, http_server: HTTPServer) -> None:
@@ -346,8 +346,6 @@ class Server(BaseServer):
     at the same time. To do that, it is necessary to use ``BaseServer`` and
     coordinate the three components above explicitly.
 
-    .. autoclasstoc::
-
     '''
 
     def __init__(self, applications: Mapping[str, Application | ModifyDoc] | Application | ModifyDoc,
@@ -394,13 +392,13 @@ class Server(BaseServer):
         ``BokehTornado``.
 
         '''
-        log.info("Starting Bokeh server version %s (running on Tornado %s)" % (__version__, tornado_version))
+        log.info(f"Starting Bokeh server version {__version__} (running on Tornado {tornado_version})")
 
         opts = _ServerOpts(kwargs)
 
         if opts.num_procs > 1 and io_loop is not None:
             raise RuntimeError(
-                "Setting both num_procs and io_loop in Server is incompatible. Use BaseServer to coordinate an explicit IOLoop and multi-process HTTPServer"
+                "Setting both num_procs and io_loop in Server is incompatible. Use BaseServer to coordinate an explicit IOLoop and multi-process HTTPServer",
             )
 
         if opts.num_procs > 1 and sys.platform == "win32":
@@ -424,15 +422,22 @@ class Server(BaseServer):
             sockets = [netutil.bind_unix_socket(opts.unix_socket)]
             self._unix_socket = opts.unix_socket
             self._address, self._port = None, None
-            extra_websocket_origins = []
+            if opts.allow_websocket_origin:
+                extra_websocket_origins = create_hosts_allowlist(opts.allow_websocket_origin, None)
+            else:
+                extra_websocket_origins = []
         else:
             sockets, self._port = bind_sockets(opts.address, opts.port)
             self._address = opts.address
 
             extra_websocket_origins = create_hosts_allowlist(opts.allow_websocket_origin, self.port)
+
+        self._absolute_url = server_url(self._address, self._port, opts.ssl_certfile is not None)
+
         try:
             tornado_app = BokehTornado(applications,
                                        extra_websocket_origins=extra_websocket_origins,
+                                       absolute_url=self._absolute_url,
                                        prefix=opts.prefix,
                                        index=opts.index,
                                        websocket_max_message_size_bytes=opts.websocket_max_message_size,
