@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -236,8 +236,6 @@ class BokehTornado(TornadoApplication):
 
     Any additional keyword arguments are passed to ``tornado.web.Application``.
 
-    .. autoclasstoc::
-
     '''
 
     _loop: IOLoop
@@ -253,6 +251,8 @@ class BokehTornado(TornadoApplication):
 
     def __init__(self,
                  applications: Mapping[str, Application | ModifyDoc] | Application | ModifyDoc,
+                 *,
+                 absolute_url: str | None = None,
                  prefix: str | None = None,
                  extra_websocket_origins: Sequence[str] | None = None,
                  extra_patterns: URLRoutes | None = None,
@@ -297,6 +297,8 @@ class BokehTornado(TornadoApplication):
             if all(not isinstance(handler, DocumentLifecycleHandler) for handler in app._handlers):
                 app.add(DocumentLifecycleHandler())
 
+        self._absolute_url = absolute_url
+
         if prefix is None:
             prefix = ""
         prefix = prefix.strip("/")
@@ -614,8 +616,8 @@ class BokehTornado(TornadoApplication):
 
         '''
         mode = settings.resources(default="server")
-        if mode == "server":
-            root_url = urljoin(absolute_url, self._prefix) if absolute_url else self._prefix
+        if mode == "server" or mode == "server-dev":
+            root_url = urljoin(absolute_url or self._absolute_url or "", self._prefix)
             return Resources(mode="server", root_url=root_url, path_versioner=StaticHandler.append_version)
         return Resources(mode=mode)
 
