@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -126,7 +126,6 @@ from typing import (
     Generic,
     Literal,
     Sequence,
-    Type,
     TypeVar,
     Union,
     cast,
@@ -328,7 +327,7 @@ class _Unset: pass
 
 T = TypeVar("T")
 
-Unset: TypeAlias = Union[T, Type[_Unset]]
+Unset: TypeAlias = Union[T, type[_Unset]]
 
 def is_dev() -> bool:
     return convert_bool(os.environ.get("BOKEH_DEV", False))
@@ -439,6 +438,9 @@ class PrioritizedSetting(Generic[T]):
     def __set__(self, instance: Any, value: str | T) -> None:
         self.set_value(value)
 
+    def __delete__(self, instance: Any) -> None:
+        self.unset_value()
+
     def set_value(self, value: str | T) -> None:
         ''' Specify a value for this setting programmatically.
 
