@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -102,7 +102,7 @@ class BokehGalleryDirective(BokehDirective):
                     "img": str(path.with_suffix("")),
                     "alt": detail.get("alt"),
                     "title": path.stem,
-                    "desc": detail.get("desc", None)
+                    "desc": detail.get("desc", None),
                 })
 
         rst_text = GALLERY_PAGE.render(opts=opts)
