@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -68,7 +68,7 @@ def get_sphinx_resources(include_bokehjs_api=False):
         else:
             resources = Resources(mode="cdn", version=docs_cdn)
     if include_bokehjs_api:
-        resources.js_components.append("bokeh-api")
+        resources.components.append("bokeh-api")
     return resources
 
 # -----------------------------------------------------------------------------
