@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -28,7 +28,7 @@ json = {
             "axis_label_text_color": "#5B5B5B",
             "axis_label_text_font": "Calibri Light",
             "axis_label_text_font_size": "1.15em",
-            "axis_label_text_font_style": "bold"
+            "axis_label_text_font_style": "bold",
         },
 
         "Legend": {
@@ -42,10 +42,10 @@ json = {
             "label_text_font_style": "bold",
 
             "border_line_alpha": 0,
-            "background_fill_alpha": 0.25
+            "background_fill_alpha": 0.25,
         },
 
-        "ColorBar": {
+        "BaseColorBar": {
             "title_text_color": "#5B5B5B",
             "title_text_font": "Calibri Light",
             "title_text_font_size": "1.15em",
@@ -57,7 +57,7 @@ json = {
             "major_label_text_font_style": "bold",
 
             "major_tick_line_alpha": 0,
-            "bar_line_alpha": 0
+            "bar_line_alpha": 0,
         },
 
         "Title": {
@@ -65,6 +65,6 @@ json = {
             "text_font": "Calibri Light",
             "text_font_size": "1.25em",
             "text_font_style": "bold",
-        }
-    }
+        },
+    },
 }
