@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,12 +11,12 @@ json = {
             "background_fill_color": "#20262B",
             "border_fill_color": "#15191C",
             "outline_line_color": "#E0E0E0",
-            "outline_line_alpha": 0.25
+            "outline_line_alpha": 0.25,
         },
 
         "Grid": {
             "grid_line_color": "#E0E0E0",
-            "grid_line_alpha": 0.25
+            "grid_line_alpha": 0.25,
         },
 
         "Axis": {
@@ -37,7 +37,7 @@ json = {
             "axis_label_text_color": "#E0E0E0",
             "axis_label_text_font": "Helvetica",
             "axis_label_text_font_size": "1.25em",
-            "axis_label_text_font_style": "normal"
+            "axis_label_text_font_style": "normal",
         },
 
         "Legend": {
@@ -51,7 +51,7 @@ json = {
 
             "border_line_alpha": 0,
             "background_fill_alpha": 0.25,
-            "background_fill_color": "#20262B"
+            "background_fill_color": "#20262B",
         },
 
         "BaseColorBar": {
@@ -66,13 +66,13 @@ json = {
 
             "background_fill_color": "#15191C",
             "major_tick_line_alpha": 0,
-            "bar_line_alpha": 0
+            "bar_line_alpha": 0,
         },
 
         "Title": {
             "text_color": "#E0E0E0",
             "text_font": "Helvetica",
-            "text_font_size": "1.15em"
-        }
-    }
+            "text_font_size": "1.15em",
+        },
+    },
 }
