@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,12 +22,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import (
-    TYPE_CHECKING,
-    Sequence,
-    Tuple,
-    Union,
-)
+from typing import TYPE_CHECKING, Sequence, Union
 
 # Bokeh imports
 from .core.property.vectorization import Expr, Field
@@ -36,6 +31,7 @@ from .models.mappers import (
     CategoricalColorMapper,
     CategoricalMarkerMapper,
     CategoricalPatternMapper,
+    EqHistColorMapper,
     LinearColorMapper,
     LogColorMapper,
 )
@@ -56,6 +52,7 @@ if TYPE_CHECKING:
 __all__ = (
     'cumsum',
     'dodge',
+    'eqhist_cmap',
     'factor_cmap',
     'factor_hatch',
     'factor_mark',
@@ -71,7 +68,7 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 if TYPE_CHECKING:
-    Factors: TypeAlias = Union[Sequence[str], Sequence[Tuple[str, str]], Sequence[Tuple[str, str, str]]]
+    Factors: TypeAlias = Union[Sequence[str], Sequence[tuple[str, str]], Sequence[tuple[str, str, str]]]
 
 def cumsum(field_name: str, include_zero: bool = False) -> Expr:
     ''' Create a ``DataSpec`` dict to generate a ``CumSum`` expression
@@ -119,8 +116,61 @@ def dodge(field_name: str, value: float, range: Range | None = None) -> Field:
     '''
     return Field(field_name, Dodge(value=value, range=range))
 
-def factor_cmap(field_name: str, palette: Sequence[ColorLike], factors: Factors,
-        start: float = 0, end: float | None = None, nan_color: ColorLike = "gray") -> Field:
+def eqhist_cmap(
+    field_name: str,
+    palette: Sequence[ColorLike],
+    low: float,
+    high: float,
+    low_color: ColorLike | None = None,
+    high_color: ColorLike | None = None,
+    nan_color: ColorLike = "gray",
+) -> Field:
+    ''' Create a ``DataSpec`` dict that applies a client-side
+    ``EqHistColorMapper`` transformation to a ``ColumnDataSource`` column.
+
+    Args:
+        field_name (str) : a field name to configure ``DataSpec`` with
+
+        palette (seq[color]) : a list of colors to use for colormapping
+
+        low (float) : a minimum value of the range to map into the palette.
+            Values below this are clamped to ``low``.
+
+        high (float) : a maximum value of the range to map into the palette.
+            Values above this are clamped to ``high``.
+
+        low_color (color, optional) : color to be used if data is lower than
+            ``low`` value. If None, values lower than ``low`` are mapped to the
+            first color in the palette. (default: None)
+
+        high_color (color, optional) : color to be used if data is higher than
+            ``high`` value. If None, values higher than ``high`` are mapped to
+            the last color in the palette. (default: None)
+
+        nan_color (color, optional) : a default color to use when mapping data
+            from a column does not succeed (default: "gray")
+
+    '''
+    return Field(
+        field_name,
+        EqHistColorMapper(
+            palette=palette,
+            low=low,
+            high=high,
+            nan_color=nan_color,
+            low_color=low_color,
+            high_color=high_color,
+        ),
+    )
+
+def factor_cmap(
+    field_name: str,
+    palette: Sequence[ColorLike],
+    factors: Factors,
+    start: float = 0,
+    end: float | None = None,
+    nan_color: ColorLike = "gray",
+) -> Field:
     ''' Create a ``DataSpec`` dict that applies a client-side
     ``CategoricalColorMapper`` transformation to a ``ColumnDataSource``
     column.
@@ -130,7 +180,7 @@ def factor_cmap(field_name: str, palette: Sequence[ColorLike], factors: Factors,
 
         palette (seq[color]) : a list of colors to use for colormapping
 
-        factors (seq) : a sequences of categorical factors corresponding to
+        factors (seq) : a sequence of categorical factors corresponding to
             the palette
 
         start (int, optional) : a start slice index to apply when the column
@@ -154,11 +204,16 @@ def factor_cmap(field_name: str, palette: Sequence[ColorLike], factors: Factors,
             start=start,
             end=end,
             nan_color=nan_color,
-        )
+        ),
     )
 
-def factor_hatch(field_name: str, patterns: Sequence[str], factors: Factors,
-        start: float = 0, end: float | None = None) -> Field:
+def factor_hatch(
+    field_name: str,
+    patterns: Sequence[str],
+    factors: Factors,
+    start: float = 0,
+    end: float | None = None,
+) -> Field:
     ''' Create a ``DataSpec`` dict that applies a client-side
     ``CategoricalPatternMapper`` transformation to a ``ColumnDataSource``
     column.
@@ -190,11 +245,16 @@ def factor_hatch(field_name: str, patterns: Sequence[str], factors: Factors,
             factors=factors,
             start=start,
             end=end,
-        )
+        ),
     )
 
-def factor_mark(field_name: str, markers: Sequence[str], factors: Factors,
-        start: float = 0, end: float | None = None) -> Field:
+def factor_mark(
+    field_name: str,
+    markers: Sequence[str],
+    factors: Factors,
+    start: float = 0,
+    end: float | None = None,
+) -> Field:
     ''' Create a ``DataSpec`` dict that applies a client-side
     ``CategoricalMarkerMapper`` transformation to a ``ColumnDataSource``
     column.
@@ -228,11 +288,16 @@ def factor_mark(field_name: str, markers: Sequence[str], factors: Factors,
             factors=factors,
             start=start,
             end=end,
-        )
+        ),
     )
 
-def jitter(field_name: str, width: float, mean: float = 0,
-        distribution: JitterRandomDistributionType = "uniform", range: Range | None = None) -> Field:
+def jitter(
+    field_name: str,
+    width: float,
+    mean: float = 0,
+    distribution: JitterRandomDistributionType = "uniform",
+    range: Range | None = None,
+) -> Field:
     ''' Create a ``DataSpec`` dict that applies a client-side ``Jitter``
     transformation to a ``ColumnDataSource`` column.
 
@@ -261,12 +326,19 @@ def jitter(field_name: str, width: float, mean: float = 0,
             width=width,
             distribution=distribution,
             range=range,
-        )
+        ),
     )
 
-def linear_cmap(field_name: str, palette: Sequence[ColorLike], low: float, high: float,
-        low_color: ColorLike | None = None, high_color: ColorLike | None = None, nan_color: ColorLike = "gray") -> Field:
-    ''' Create a ``DataSpec`` dict that applyies a client-side
+def linear_cmap(
+    field_name: str,
+    palette: Sequence[ColorLike],
+    low: float,
+    high: float,
+    low_color: ColorLike | None = None,
+    high_color: ColorLike | None = None,
+    nan_color: ColorLike = "gray",
+) -> Field:
+    ''' Create a ``DataSpec`` dict that applies a client-side
     ``LinearColorMapper`` transformation to a ``ColumnDataSource`` column.
 
     Args:
@@ -301,11 +373,18 @@ def linear_cmap(field_name: str, palette: Sequence[ColorLike], low: float, high:
             nan_color=nan_color,
             low_color=low_color,
             high_color=high_color,
-        )
+        ),
     )
 
-def log_cmap(field_name: str, palette: Sequence[ColorLike], low: float, high: float,
-        low_color: ColorLike | None = None, high_color: ColorLike | None = None, nan_color: ColorLike = "gray") -> Field:
+def log_cmap(
+    field_name: str,
+    palette: Sequence[ColorLike],
+    low: float,
+    high: float,
+    low_color: ColorLike | None = None,
+    high_color: ColorLike | None = None,
+    nan_color: ColorLike = "gray",
+) -> Field:
     ''' Create a ``DataSpec`` dict that applies a client-side ``LogColorMapper``
     transformation to a ``ColumnDataSource`` column.
 
@@ -341,7 +420,7 @@ def log_cmap(field_name: str, palette: Sequence[ColorLike], low: float, high: fl
             nan_color=nan_color,
             low_color=low_color,
             high_color=high_color,
-        )
+        ),
     )
 
 def stack(*fields: str) -> Expr:
