@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -33,13 +33,9 @@ from os.path import (
     isabs,
     join,
 )
+from pathlib import Path
 from subprocess import PIPE, Popen
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Sequence,
-)
+from typing import Any, Callable, Sequence
 
 # Bokeh imports
 from ..core.has_props import HasProps
@@ -74,7 +70,7 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-class AttrDict(Dict[str, Any]):
+class AttrDict(dict[str, Any]):
     ''' Provide a dict subclass that supports access by named attributes.
 
     '''
@@ -260,7 +256,7 @@ class CustomModel:
                 impl = TypeScript(impl)
 
         if isinstance(impl, Inline) and impl.file is None:
-            file = "%s%s.ts" % (self.file + ":" if self.file else "", self.name)
+            file = f"{self.file + ':' if self.file else ''}{self.name}.ts"
             impl = impl.__class__(impl.code, file)
 
         return impl
@@ -436,7 +432,7 @@ def _crlf_cr_2_lf(s: str) -> str:
     return re.sub(r"\\r\\n|\\r|\\n", r"\\n", s)
 
 def _run(app: str, argv: list[str], input: dict[str, Any] | None = None) -> str:
-    proc = Popen([app] + argv, stdout=PIPE, stderr=PIPE, stdin=PIPE)
+    proc = Popen([app, *argv], stdout=PIPE, stderr=PIPE, stdin=PIPE)
     (stdout, errout) = proc.communicate(input=None if input is None else json.dumps(input).encode())
 
     if proc.returncode != 0:
@@ -507,14 +503,15 @@ def _bundle_models(custom_models: dict[str, CustomModel]) -> str:
     exports = []
     modules = []
 
-    with open(join(bokehjs_dir, "js", "bokeh.json"), encoding="utf-8") as f:
-        bokeh = json.load(f)
+    lib_dir = Path(bokehjs_dir) / "js" / "lib"
+    known_modules: set[str] = set()
 
-    known_modules = set()
-    for artifact in bokeh["artifacts"]:
-        canonical = artifact["module"].get("canonical")
-        if canonical is not None:
-            known_modules.add(canonical)
+    for path in lib_dir.rglob("*.d.ts"):
+        s = str(path.relative_to(lib_dir))
+        if s.endswith(".d.ts"):
+            s = s[:-5] # TODO: removesuffix() (Py 3.9+)
+        s = s.replace(os.path.sep, "/")
+        known_modules.add(s)
 
     custom_impls = _compile_models(custom_models)
 
