@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,14 +21,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import (
-    Dict,
-    Generic,
-    List,
-    Set,
-    TypeVar,
-    cast,
-)
+from typing import Generic, TypeVar, cast
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -52,7 +45,7 @@ class MultiValuedDict(Generic[K, V]):
 
     '''
 
-    _dict: Dict[K, V | Set[V]]
+    _dict: dict[K, V | set[V]]
 
     def __init__(self) -> None:
         '''
@@ -77,11 +70,11 @@ class MultiValuedDict(Generic[K, V]):
         if existing is None:
             self._dict[key] = value
         elif isinstance(existing, set):
-            cast(Set[V], existing).add(value) # XXX: V does not exclude `Set[_]`
+            cast(set[V], existing).add(value) # XXX: V does not exclude `set[_]`
         else:
             self._dict[key] = {existing, value}
 
-    def get_all(self, k: K) -> List[V]:
+    def get_all(self, k: K) -> list[V]:
         '''
 
         '''
@@ -89,7 +82,7 @@ class MultiValuedDict(Generic[K, V]):
         if existing is None:
             return []
         elif isinstance(existing, set):
-            return list(cast(Set[V], existing))
+            return list(cast(set[V], existing))
         else:
             return [existing]
 
@@ -99,7 +92,7 @@ class MultiValuedDict(Generic[K, V]):
         '''
         existing = self._dict.get(k)
         if isinstance(existing, set):
-            existing = cast(Set[V], existing)
+            existing = cast(set[V], existing)
             if len(existing) == 1:
                 return next(iter(existing))
             else:
@@ -116,7 +109,7 @@ class MultiValuedDict(Generic[K, V]):
 
         existing = self._dict.get(key)
         if isinstance(existing, set):
-            existing = cast(Set[V], existing)
+            existing = cast(set[V], existing)
             existing.discard(value)
             if len(existing) == 0:
                 del self._dict[key]
