@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -18,7 +18,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import TYPE_CHECKING, Tuple, overload
+from typing import TYPE_CHECKING, overload
 
 # Bokeh imports
 from .warnings import BokehDeprecationWarning, warn
@@ -34,7 +34,7 @@ __all__ = (
     'deprecated',
 )
 
-Version: TypeAlias = Tuple[int, int, int]
+Version: TypeAlias = tuple[int, int, int]
 
 #-----------------------------------------------------------------------------
 # General API
@@ -61,7 +61,7 @@ def deprecated(since_or_msg: Version | str,
 
         major, minor, patch = since_or_msg
         since = f"{major}.{minor}.{patch}"
-        message = f"{old} was deprecated in Bokeh {since} and will be removed, use {new} instead."
+        message = f"{old!r} was deprecated in Bokeh {since} and will be removed, use {new!r} instead."
         if extra is not None:
             message += " " + extra.strip()
     else:
