@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,10 +22,10 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import Any, Dict
+from typing import Any
 
 # Bokeh imports
-from ..core.has_props import HasProps
+from ..core.has_props import HasProps, Local
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -39,7 +39,7 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-class Options(HasProps):
+class Options(HasProps, Local):
     ''' Leverage the Bokeh properties type system for specifying and
     validating configuration options.
 
@@ -57,17 +57,17 @@ class Options(HasProps):
     Then a ``ConnectOpts`` can be created by passing a dictionary
     containing keys and values corresponding to the configuration options,
     as well as any additional keys and values. The items corresponding
-    to the properties on ``ConnectOpts`` will be ***removed*** from the
+    to the properties on ``ConnectOpts`` will be **removed** from the
     dictionary. This can be useful for functions that accept their own
     set of config keyword arguments in addition to some set of Bokeh model
     properties.
 
     '''
 
-    def __init__(self, kw: Dict[str, Any]) -> None:
+    def __init__(self, kw: dict[str, Any]) -> None:
 
         # remove any items that match our declared properties
-        props: Dict[str, Any] = {}
+        props: dict[str, Any] = {}
         for k in self.properties():
             if k in kw:
                 props[k] = kw.pop(k)
