@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -96,6 +96,7 @@ __all__ = (
     'convert_timedelta_type',
     'is_datetime_type',
     'is_timedelta_type',
+    'make_globally_unique_css_safe_id',
     'make_globally_unique_id',
     'make_id',
     'transform_array',
@@ -110,7 +111,7 @@ def is_datetime_type(obj: Any) -> TypeGuard[dt.time | dt.datetime | np.datetime6
     ''' Whether an object is any date, time, or datetime type recognized by
     Bokeh.
 
-    Arg:
+    Args:
         obj (object) : the object to test
 
     Returns:
@@ -124,7 +125,7 @@ def is_datetime_type(obj: Any) -> TypeGuard[dt.time | dt.datetime | np.datetime6
 def is_timedelta_type(obj: Any) -> TypeGuard[dt.timedelta | np.timedelta64]:
     ''' Whether an object is any timedelta type recognized by Bokeh.
 
-    Arg:
+    Args:
         obj (object) : the object to test
 
     Returns:
@@ -149,7 +150,7 @@ def convert_timedelta_type(obj: dt.timedelta | np.timedelta64) -> float:
     ''' Convert any recognized timedelta value to floating point absolute
     milliseconds.
 
-    Arg:
+    Args:
         obj (object) : the object to convert
 
     Returns:
@@ -168,7 +169,7 @@ def convert_datetime_type(obj: Any | pd.Timestamp | pd.Timedelta | dt.datetime |
     ''' Convert any recognized date, time, or datetime value to floating point
     milliseconds since epoch.
 
-    Arg:
+    Args:
         obj (object) : the object to convert
 
     Returns:
@@ -277,6 +278,26 @@ def make_globally_unique_id() -> ID:
     '''
     return ID(str(uuid.uuid4()))
 
+def make_globally_unique_css_safe_id() -> ID:
+    ''' Return a globally unique CSS-safe UUID.
+
+    Some situations, e.g. id'ing dynamically created Divs in HTML documents,
+    always require globally unique IDs. ID generated with this function can
+    be used in APIs like ``document.querySelector("#id")``.
+
+    Returns:
+        str
+
+    '''
+    max_iter = 100
+
+    for _i in range(0, max_iter):
+        id = make_globally_unique_id()
+        if id[0].isalpha():
+            return id
+
+    return ID(f"bk-{make_globally_unique_id()}")
+
 def array_encoding_disabled(array: npt.NDArray[Any]) -> bool:
     ''' Determine whether an array may be binary encoded.
 
@@ -338,7 +359,7 @@ def transform_array(array: npt.NDArray[Any]) -> npt.NDArray[Any]:
 
     return array
 
-def transform_series(series: pd.Series[Any] | pd.Index) -> npt.NDArray[Any]:
+def transform_series(series: pd.Series[Any] | pd.Index | pd.api.extensions.ExtensionArray) -> npt.NDArray[Any]:
     ''' Transforms a Pandas series into serialized form
 
     Args:
@@ -355,7 +376,7 @@ def transform_series(series: pd.Series[Any] | pd.Index) -> npt.NDArray[Any]:
     if isinstance(series, pd.PeriodIndex):
         vals = series.to_timestamp().values  # type: ignore
     else:
-        vals = series.values
+        vals = series.to_numpy()
     return vals
 
 #-----------------------------------------------------------------------------
