@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -27,11 +27,6 @@ log = logging.getLogger(__name__)
 import inspect
 import os
 import warnings  # lgtm [py/import-and-import-from]
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from typing_extensions import Type
-
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -62,7 +57,7 @@ class BokehUserWarning(UserWarning):
 
     '''
 
-def warn(message: str, category: Type[Warning] | None = None, stacklevel: int | None = None) -> None:
+def warn(message: str, category: type[Warning] | None = None, stacklevel: int | None = None) -> None:
     if stacklevel is None:
         stacklevel = find_stack_level()
 
